# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1czetasql/public/options.proto\x12\x07zetasql\x1a google/protobuf/descriptor.proto\"\x8a\x01\n\x16LanguageFeatureOptions\x12\x1d\n\x0fideally_enabled\x18\x01 \x01(\x08:\x04true\x12\x1d\n\x0ein_development\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x32\n\x10language_version\x18\x03 \x01(\x0e\x32\x18.zetasql.LanguageVersion\"S\n\x19ResolvedASTRewriteOptions\x12\x17\n\x0f\x64\x65\x66\x61ult_enabled\x18\x01 \x01(\x08\x12\x1d\n\x0ein_development\x18\x02 \x01(\x08:\x05\x66\x61lse\"e\n\x0eRewriteOptions\x12H\n\x1cgrouping_set_rewrite_options\x18\x17 \x01(\x0b\x32\".zetasql.GroupingSetRewriteOptions*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"i\n\x19GroupingSetRewriteOptions\x12 \n\x11max_grouping_sets\x18\x01 \x01(\x03:\x05\x36\x35\x35\x33\x36\x12*\n\x1bmax_columns_in_grouping_set\x18\x02 \x01(\x03:\x05\x36\x35\x35\x33\x36\"E\n\x1a\x45rrorMessageModeForPayload\x12\'\n\x04mode\x18\x01 \x01(\x0e\x32\x19.zetasql.ErrorMessageMode*\xe0\x01\n\x0fLanguageVersion\x12\x13\n\x0fVERSION_CURRENT\x10\x01\x12 \n\x1cLANGUAGE_VERSION_UNSPECIFIED\x10\x00\x12\x10\n\x0bVERSION_1_0\x10\x90N\x12\x10\n\x0bVERSION_1_1\x10\xf8U\x12\x10\n\x0bVERSION_1_2\x10\xe0]\x12\x10\n\x0bVERSION_1_3\x10\xc8\x65\x12\x10\n\x0bVERSION_1_4\x10\xb0m\x12<\n/__LanguageVersion__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01*\x81\xad\x01\n\x0fLanguageFeature\x12\x1e\n\x1a\x46\x45\x41TURE_ANALYTIC_FUNCTIONS\x10\x01\x12\x17\n\x13\x46\x45\x41TURE_TABLESAMPLE\x10\x02\x12-\n\x1f\x46\x45\x41TURE_DISALLOW_GROUP_BY_FLOAT\x10\x03\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12\x1b\n\x17\x46\x45\x41TURE_TIMESTAMP_NANOS\x10\x05\x12\x1b\n\x17\x46\x45\x41TURE_TIMESTAMP_PICOS\x10{\x12\x43\n3FEATURE_PARSE_TIMESTAMP_WITH_PRECISION_AND_TIMEZONE\x10\xa0n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12 \n\x1c\x46\x45\x41TURE_DML_UPDATE_WITH_JOIN\x10\x06\x12\"\n\x1e\x46\x45\x41TURE_TABLE_VALUED_FUNCTIONS\x10\x08\x12%\n!FEATURE_CREATE_AGGREGATE_FUNCTION\x10\t\x12!\n\x1d\x46\x45\x41TURE_CREATE_TABLE_FUNCTION\x10\n\x12\x1b\n\x17\x46\x45\x41TURE_GROUP_BY_ROLLUP\x10\x0c\x12\x1e\n\x1a\x46\x45\x41TURE_TEMPLATE_FUNCTIONS\x10\r\x12%\n!FEATURE_CREATE_TABLE_PARTITION_BY\x10\x0e\x12#\n\x1f\x46\x45\x41TURE_CREATE_TABLE_CLUSTER_BY\x10\x0f\x12\x18\n\x14\x46\x45\x41TURE_NUMERIC_TYPE\x10\x10\x12!\n\x1d\x46\x45\x41TURE_CREATE_TABLE_NOT_NULL\x10\x11\x12*\n&FEATURE_CREATE_TABLE_FIELD_ANNOTATIONS\x10\x12\x12.\n*FEATURE_CREATE_TABLE_AS_SELECT_COLUMN_LIST\x10\x13\x12\x30\n\"FEATURE_DISALLOW_NULL_PRIMARY_KEYS\x10\x14\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12\x32\n$FEATURE_DISALLOW_PRIMARY_KEY_UPDATES\x10\x15\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12\x33\n/FEATURE_TABLESAMPLE_FROM_TABLE_VALUED_FUNCTIONS\x10\x16\x12\x16\n\x12\x46\x45\x41TURE_ENCRYPTION\x10\x17\x12#\n\x15\x46\x45\x41TURE_ANONYMIZATION\x10\x18\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x30\n\"FEATURE_ANONYMIZATION_THRESHOLDING\x10S\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12<\n.FEATURE_ANONYMIZATION_CASE_INSENSITIVE_OPTIONS\x10U\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x01\x12*\n\x1c\x46\x45\x41TURE_DIFFERENTIAL_PRIVACY\x10X\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12;\n-FEATURE_DIFFERENTIAL_PRIVACY_REPORT_FUNCTIONS\x10Y\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x37\n)FEATURE_DIFFERENTIAL_PRIVACY_THRESHOLDING\x10Z\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12?\n1FEATURE_DIFFERENTIAL_PRIVACY_MAX_ROWS_CONTRIBUTED\x10_\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x38\n*FEATURE_DIFFERENTIAL_PRIVACY_PUBLIC_GROUPS\x10\x64\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x46\n8FEATURE_DIFFERENTIAL_PRIVACY_MIN_PRIVACY_UNITS_PER_GROUP\x10h\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12(\n\x19\x46\x45\x41TURE_VECTOR_SEARCH_TVF\x10\x92\x01\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x41\n3FEATURE_DIFFERENTIAL_PRIVACY_PER_AGGREGATION_BUDGET\x10z\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x32\n#FEATURE_DIFFERENTIAL_PRIVACY_NESTED\x10\x90\x01\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12&\n\x17\x46\x45\x41TURE_TUMBLE_HOP_TVFS\x10\x93\x01\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x39\n(FEATURE_TUMBLE_HOP_TVFS_NO_TIMESTAMP_COL\x10\x94\x01\x1a\n\xda\xf1\xaa\x89\x05\x04\x08\x00\x10\x01\x12-\n\x1c\x46\x45\x41TURE_LEGACY_BINARY_CONCAT\x10\x95\x01\x1a\n\xda\xf1\xaa\x89\x05\x04\x08\x00\x10\x01\x12!\n\x1d\x46\x45\x41TURE_AGGREGATION_THRESHOLD\x10\\\x12\x15\n\x11\x46\x45\x41TURE_GEOGRAPHY\x10\x19\x12,\n(FEATURE_STRATIFIED_RESERVOIR_TABLESAMPLE\x10\x1a\x12\x18\n\x14\x46\x45\x41TURE_FOREIGN_KEYS\x10\x1b\x12 \n\x1c\x46\x45\x41TURE_BETWEEN_UINT64_INT64\x10\x1c\x12\x1c\n\x18\x46\x45\x41TURE_CHECK_CONSTRAINT\x10\x1d\x12&\n\"FEATURE_PARAMETERS_IN_GRANTEE_LIST\x10\x1e\x12\x1b\n\x17\x46\x45\x41TURE_NAMED_ARGUMENTS\x10\x1f\x12\x31\n-FEATURE_ALLOW_LEGACY_ROW_ACCESS_POLICY_SYNTAX\x10 \x12\x31\n-FEATURE_CREATE_MATERIALIZED_VIEW_PARTITION_BY\x10!\x12/\n+FEATURE_CREATE_MATERIALIZED_VIEW_CLUSTER_BY\x10\"\x12\x39\n5FEATURE_CREATE_EXTERNAL_TABLE_WITH_TABLE_ELEMENT_LIST\x10#\x12#\n\x1f\x46\x45\x41TURE_UNENFORCED_PRIMARY_KEYS\x10(\x12\x1b\n\x17\x46\x45\x41TURE_BIGNUMERIC_TYPE\x10)\x12\x1a\n\x16\x46\x45\x41TURE_EXTENDED_TYPES\x10*\x12\x15\n\x11\x46\x45\x41TURE_JSON_TYPE\x10+\x12\x30\n\"FEATURE_JSON_STRICT_NUMBER_PARSING\x10\x34\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12\x33\n/FEATURE_ENABLE_CONSTANT_EXPRESSION_IN_JSON_PATH\x10\x35\x12 \n\x1c\x46\x45\x41TURE_JSON_ARRAY_FUNCTIONS\x10:\x12+\n\'FEATURE_JSON_VALUE_EXTRACTION_FUNCTIONS\x10\x44\x12/\n+FEATURE_JSON_LAX_VALUE_EXTRACTION_FUNCTIONS\x10Q\x12&\n\"FEATURE_JSON_CONSTRUCTOR_FUNCTIONS\x10]\x12\"\n\x1e\x46\x45\x41TURE_JSON_MUTATOR_FUNCTIONS\x10\x62\x12\x1a\n\x16\x46\x45\x41TURE_JSON_QUERY_LAX\x10s\x12\"\n\x1e\x46\x45\x41TURE_JSON_CONTAINS_FUNCTION\x10t\x12\x1e\n\x1a\x46\x45\x41TURE_JSON_KEYS_FUNCTION\x10v\x12\"\n\x1d\x46\x45\x41TURE_JSON_FLATTEN_FUNCTION\x10\x89\x01\x12\x42\n4FEATURE_CREATE_EXTERNAL_TABLE_WITH_PARTITION_COLUMNS\x10/\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x19\n\x15\x46\x45\x41TURE_INTERVAL_TYPE\x10\x31\x12\x1e\n\x1a\x46\x45\x41TURE_EXTRACT_ONEOF_CASE\x10\x32\x12\x1c\n\x18\x46\x45\x41TURE_TOKENIZED_SEARCH\x10\x33\x12\x1f\n\x1b\x46\x45\x41TURE_PARAMETERIZED_TYPES\x10\x38\x12\x1d\n\x19\x46\x45\x41TURE_CREATE_TABLE_LIKE\x10\x39\x12(\n$FEATURE_CREATE_VIEW_WITH_COLUMN_LIST\x10;\x12\x30\n,FEATURE_ALTER_VIEWS_ALTER_COLUMN_SET_OPTIONS\x10W\x12G\n8FEATURE_ALTER_MATERIALIZED_VIEW_ALTER_COLUMN_SET_OPTIONS\x10\x97\x01\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12(\n\x1a\x46\x45\x41TURE_CREATE_TABLE_CLONE\x10<\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12 \n\x12\x46\x45\x41TURE_CLONE_DATA\x10=\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x30\n\"FEATURE_ALTER_COLUMN_SET_DATA_TYPE\x10>\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12!\n\x1d\x46\x45\x41TURE_CREATE_SNAPSHOT_TABLE\x10?\x12,\n(FEATURE_FUNCTION_ARGUMENTS_WITH_DEFAULTS\x10@\x12\x31\n-FEATURE_CREATE_EXTERNAL_TABLE_WITH_CONNECTION\x10\x41\x12\x1d\n\x19\x46\x45\x41TURE_CREATE_TABLE_COPY\x10\x42\x12%\n!FEATURE_ALTER_TABLE_RENAME_COLUMN\x10\x43\x12\x39\n)FEATURE_DISALLOW_LEGACY_UNICODE_COLLATION\x10\x45\x1a\n\xda\xf1\xaa\x89\x05\x04\x08\x00\x10\x01\x12\x36\n2FEATURE_ALLOW_MISSING_PATH_EXPRESSION_IN_ALTER_DDL\x10\x46\x12!\n\x1d\x46\x45\x41TURE_TIME_BUCKET_FUNCTIONS\x10G\x12,\n\x1e\x46\x45\x41TURE_INVERSE_TRIG_FUNCTIONS\x10H\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x16\n\x12\x46\x45\x41TURE_RANGE_TYPE\x10I\x12\'\n\x19\x46\x45\x41TURE_NON_SQL_PROCEDURE\x10K\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12$\n FEATURE_ROUND_WITH_ROUNDING_MODE\x10L\x12\x1a\n\x16\x46\x45\x41TURE_CBRT_FUNCTIONS\x10M\x12\x33\n!FEATURE_RADIANS_DEGREES_FUNCTIONS\x10\x9dn\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12*\n\x1a\x46\x45\x41TURE_SPANNER_LEGACY_DDL\x10N\x1a\n\xda\xf1\xaa\x89\x05\x04\x08\x00\x10\x01\x12/\n!FEATURE_DISABLE_ARRAY_MIN_AND_MAX\x10O\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12?\n1FEATURE_STRICT_FUNCTION_DEFAULT_ARG_TYPE_COERCION\x10P\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12 \n\x12\x46\x45\x41TURE_PROTO_BASE\x10R\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12/\n!FEATURE_DISABLE_ARRAY_SUM_AND_AVG\x10T\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12\x36\n(FEATURE_CREATE_VIEWS_WITH_COLUMN_OPTIONS\x10V\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12(\n$FEATURE_CREATE_TABLE_WITH_CONNECTION\x10[\x12.\n FEATURE_DISABLE_OUTER_JOIN_ARRAY\x10^\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12\x31\n#FEATURE_EXTERNAL_SECURITY_PROCEDURE\x10`\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x32\n.FEATURE_CREATE_MATERIALIZED_VIEW_AS_REPLICA_OF\x10\x61\x12,\n\x1d\x46\x45\x41TURE_CREATE_LOCALITY_GROUP\x10\x88\x01\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x32\n\"FEATURE_ENABLE_ALTER_ARRAY_OPTIONS\x10\x66\x1a\n\xda\xf1\xaa\x89\x05\x04\x08\x00\x10\x01\x12\x11\n\rFEATURE_PIPES\x10\x65\x12 \n\x1c\x46\x45\x41TURE_PIPE_STATIC_DESCRIBE\x10p\x12\x17\n\x13\x46\x45\x41TURE_PIPE_ASSERT\x10q\x12\x1e\n\x10\x46\x45\x41TURE_PIPE_LOG\x10x\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x13\n\x0f\x46\x45\x41TURE_PIPE_IF\x10}\x12\x16\n\x11\x46\x45\x41TURE_PIPE_FORK\x10\x80\x01\x12\x15\n\x10\x46\x45\x41TURE_PIPE_TEE\x10\x83\x01\x12\x16\n\x11\x46\x45\x41TURE_PIPE_WITH\x10\x87\x01\x12\x1d\n\x18\x46\x45\x41TURE_PIPE_EXPORT_DATA\x10\x81\x01\x12\x1e\n\x19\x46\x45\x41TURE_PIPE_CREATE_TABLE\x10\x82\x01\x12\x18\n\x13\x46\x45\x41TURE_PIPE_INSERT\x10\x85\x01\x12?\n0FEATURE_PIPE_AGGREGATE_WITH_DIFFERENTIAL_PRIVACY\x10\x8e\x01\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12 \n\x1c\x46\x45\x41TURE_GENERATED_BY_DEFAULT\x10g\x12\x30\n,FEATURE_ENFORCE_MICROS_MODE_IN_INTERVAL_TYPE\x10i\x12\'\n#FEATURE_ALTER_COLUMN_DROP_GENERATED\x10j\x12\x33\n.FEATURE_ALTER_COLUMN_SET_GENERATED_AS_IDENTITY\x10\x8d\x01\x12\x31\n!FEATURE_DISABLE_TEXTMAPPER_PARSER\x10k\x1a\n\x08\x01\xda\xf1\xaa\x89\x05\x02\x08\x00\x12\x1c\n\x18\x46\x45\x41TURE_IDENTITY_COLUMNS\x10m\x12\x1f\n\x1b\x46\x45\x41TURE_EXTERNAL_SCHEMA_DDL\x10o\x12:\n6FEATURE_TEMPLATED_SQL_FUNCTION_RESOLVE_WITH_TYPED_ARGS\x10r\x12/\n!FEATURE_CREATE_INDEX_PARTITION_BY\x10u\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x30\n\"FEATURE_TO_JSON_UNSUPPORTED_FIELDS\x10w\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12@\n2FEATURE_PROPERTY_GRAPH_ENFORCE_EXPLICIT_PROPERTIES\x10y\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12.\n\x1f\x46\x45\x41TURE_JSON_SUBFIELDS_WITH_SET\x10\x8a\x01\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12!\n\x1c\x46\x45\x41TURE_JSON_TYPE_COMPARISON\x10\x8b\x01\x12\x35\n1FEATURE_TIMESTAMP_FROM_UNIX_FUNCTIONS_WITH_UINT64\x10~\x12\x38\n*FEATURE_TABLE_SYNTAX_RESOLVE_ARGUMENT_LAST\x10\x7f\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12\x43\n4FEATURE_DISABLE_VALIDATE_REWRITERS_REFER_TO_BUILTINS\x10\x86\x01\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12,\n\x1d\x46\x45\x41TURE_PROCEDURES_IN_MODULES\x10\x96\x01\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12\x34\n%FEATURE_STATEMENT_WITH_PIPE_OPERATORS\x10\x91\x01\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12\x31\n\"FEATURE_TOP_LEVEL_TABLE_STATEMENTS\x10\x98\x01\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12(\n\x18\x46\x45\x41TURE_ORDER_BY_COLLATE\x10\xf9U\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xf8U\x12\'\n\x1e\x46\x45\x41TURE_V_1_1_ORDER_BY_COLLATE\x10\xf9U\x1a\x02\x08\x01\x12(\n\x18\x46\x45\x41TURE_WITH_ON_SUBQUERY\x10\xfaU\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xf8U\x12\'\n\x1e\x46\x45\x41TURE_V_1_1_WITH_ON_SUBQUERY\x10\xfaU\x1a\x02\x08\x01\x12\x32\n\"FEATURE_SELECT_STAR_EXCEPT_REPLACE\x10\xfbU\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xf8U\x12\x31\n(FEATURE_V_1_1_SELECT_STAR_EXCEPT_REPLACE\x10\xfbU\x1a\x02\x08\x01\x12-\n\x1d\x46\x45\x41TURE_ORDER_BY_IN_AGGREGATE\x10\xfcU\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xf8U\x12,\n#FEATURE_V_1_1_ORDER_BY_IN_AGGREGATE\x10\xfcU\x1a\x02\x08\x01\x12\x32\n\"FEATURE_CAST_DIFFERENT_ARRAY_TYPES\x10\xfdU\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xf8U\x12\x31\n(FEATURE_V_1_1_CAST_DIFFERENT_ARRAY_TYPES\x10\xfdU\x1a\x02\x08\x01\x12&\n\x16\x46\x45\x41TURE_ARRAY_EQUALITY\x10\xfeU\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xf8U\x12%\n\x1c\x46\x45\x41TURE_V_1_1_ARRAY_EQUALITY\x10\xfeU\x1a\x02\x08\x01\x12*\n\x1a\x46\x45\x41TURE_LIMIT_IN_AGGREGATE\x10\xffU\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xf8U\x12)\n FEATURE_V_1_1_LIMIT_IN_AGGREGATE\x10\xffU\x1a\x02\x08\x01\x12+\n\x1b\x46\x45\x41TURE_HAVING_IN_AGGREGATE\x10\x80V\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xf8U\x12*\n!FEATURE_V_1_1_HAVING_IN_AGGREGATE\x10\x80V\x1a\x02\x08\x01\x12:\n*FEATURE_NULL_HANDLING_MODIFIER_IN_ANALYTIC\x10\x81V\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xf8U\x12\x39\n0FEATURE_V_1_1_NULL_HANDLING_MODIFIER_IN_ANALYTIC\x10\x81V\x1a\x02\x08\x01\x12;\n+FEATURE_NULL_HANDLING_MODIFIER_IN_AGGREGATE\x10\x82V\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xf8U\x12:\n1FEATURE_V_1_1_NULL_HANDLING_MODIFIER_IN_AGGREGATE\x10\x82V\x1a\x02\x08\x01\x12-\n\x1d\x46\x45\x41TURE_FOR_SYSTEM_TIME_AS_OF\x10\x83V\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xf8U\x12,\n#FEATURE_V_1_1_FOR_SYSTEM_TIME_AS_OF\x10\x83V\x1a\x02\x08\x01\x12\"\n\x12\x46\x45\x41TURE_CIVIL_TIME\x10\xe1]\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xe0]\x12!\n\x18\x46\x45\x41TURE_V_1_2_CIVIL_TIME\x10\xe1]\x1a\x02\x08\x01\x12*\n\x1a\x46\x45\x41TURE_SAFE_FUNCTION_CALL\x10\xe2]\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xe0]\x12)\n FEATURE_V_1_2_SAFE_FUNCTION_CALL\x10\xe2]\x1a\x02\x08\x01\x12\'\n\x17\x46\x45\x41TURE_GROUP_BY_STRUCT\x10\xe3]\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xe0]\x12&\n\x1d\x46\x45\x41TURE_V_1_2_GROUP_BY_STRUCT\x10\xe3]\x1a\x02\x08\x01\x12\x31\n!FEATURE_PROTO_EXTENSIONS_WITH_NEW\x10\xe4]\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xe0]\x12\x30\n\'FEATURE_V_1_2_PROTO_EXTENSIONS_WITH_NEW\x10\xe4]\x1a\x02\x08\x01\x12&\n\x16\x46\x45\x41TURE_GROUP_BY_ARRAY\x10\xe5]\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xe0]\x12%\n\x1c\x46\x45\x41TURE_V_1_2_GROUP_BY_ARRAY\x10\xe5]\x1a\x02\x08\x01\x12\x31\n!FEATURE_PROTO_EXTENSIONS_WITH_SET\x10\xe6]\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xe0]\x12\x30\n\'FEATURE_V_1_2_PROTO_EXTENSIONS_WITH_SET\x10\xe6]\x1a\x02\x08\x01\x12\x35\n%FEATURE_CORRELATED_REFS_IN_NESTED_DML\x10\xe7]\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xe0]\x12\x34\n+FEATURE_V_1_2_CORRELATED_REFS_IN_NESTED_DML\x10\xe7]\x1a\x02\x08\x01\x12)\n\x19\x46\x45\x41TURE_WEEK_WITH_WEEKDAY\x10\xe8]\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xe0]\x12(\n\x1f\x46\x45\x41TURE_V_1_2_WEEK_WITH_WEEKDAY\x10\xe8]\x1a\x02\x08\x01\x12/\n\x1f\x46\x45\x41TURE_ARRAY_ELEMENTS_WITH_SET\x10\xe9]\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xe0]\x12.\n%FEATURE_V_1_2_ARRAY_ELEMENTS_WITH_SET\x10\xe9]\x1a\x02\x08\x01\x12\x38\n(FEATURE_NESTED_UPDATE_DELETE_WITH_OFFSET\x10\xea]\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xe0]\x12\x37\n.FEATURE_V_1_2_NESTED_UPDATE_DELETE_WITH_OFFSET\x10\xea]\x1a\x02\x08\x01\x12)\n\x19\x46\x45\x41TURE_GENERATED_COLUMNS\x10\xeb]\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xe0]\x12(\n\x1f\x46\x45\x41TURE_V_1_2_GENERATED_COLUMNS\x10\xeb]\x1a\x02\x08\x01\x12-\n\x1d\x46\x45\x41TURE_PROTO_DEFAULT_IF_NULL\x10\xc9\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12,\n#FEATURE_V_1_3_PROTO_DEFAULT_IF_NULL\x10\xc9\x65\x1a\x02\x08\x01\x12*\n\x1a\x46\x45\x41TURE_EXTRACT_FROM_PROTO\x10\xca\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12)\n FEATURE_V_1_3_EXTRACT_FROM_PROTO\x10\xca\x65\x1a\x02\x08\x01\x12\x45\n3FEATURE_DEPRECATED_DISALLOW_PROTO3_HAS_SCALAR_FIELD\x10\xcb\x65\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x08\x00\x18\xc8\x65\x12\x42\n9FEATURE_V_1_3_DEPRECATED_DISALLOW_PROTO3_HAS_SCALAR_FIELD\x10\xcb\x65\x1a\x02\x08\x01\x12&\n\x16\x46\x45\x41TURE_ARRAY_ORDERING\x10\xcc\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12%\n\x1c\x46\x45\x41TURE_V_1_3_ARRAY_ORDERING\x10\xcc\x65\x1a\x02\x08\x01\x12/\n\x1f\x46\x45\x41TURE_OMIT_INSERT_COLUMN_LIST\x10\xcd\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12.\n%FEATURE_V_1_3_OMIT_INSERT_COLUMN_LIST\x10\xcd\x65\x1a\x02\x08\x01\x12\x32\n\"FEATURE_IGNORE_PROTO3_USE_DEFAULTS\x10\xce\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x31\n(FEATURE_V_1_3_IGNORE_PROTO3_USE_DEFAULTS\x10\xce\x65\x1a\x02\x08\x01\x12&\n\x16\x46\x45\x41TURE_REPLACE_FIELDS\x10\xcf\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12%\n\x1c\x46\x45\x41TURE_V_1_3_REPLACE_FIELDS\x10\xcf\x65\x1a\x02\x08\x01\x12\x34\n$FEATURE_NULLS_FIRST_LAST_IN_ORDER_BY\x10\xd0\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x33\n*FEATURE_V_1_3_NULLS_FIRST_LAST_IN_ORDER_BY\x10\xd0\x65\x1a\x02\x08\x01\x12\x32\n\"FEATURE_ALLOW_DASHES_IN_TABLE_NAME\x10\xd1\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x31\n(FEATURE_V_1_3_ALLOW_DASHES_IN_TABLE_NAME\x10\xd1\x65\x1a\x02\x08\x01\x12*\n\x1a\x46\x45\x41TURE_CONCAT_MIXED_TYPES\x10\xd2\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12)\n FEATURE_V_1_3_CONCAT_MIXED_TYPES\x10\xd2\x65\x1a\x02\x08\x01\x12&\n\x16\x46\x45\x41TURE_WITH_RECURSIVE\x10\xd3\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12%\n\x1c\x46\x45\x41TURE_V_1_3_WITH_RECURSIVE\x10\xd3\x65\x1a\x02\x08\x01\x12\"\n\x12\x46\x45\x41TURE_PROTO_MAPS\x10\xd4\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12!\n\x18\x46\x45\x41TURE_V_1_3_PROTO_MAPS\x10\xd4\x65\x1a\x02\x08\x01\x12\x33\n#FEATURE_ENUM_VALUE_DESCRIPTOR_PROTO\x10\xd5\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x32\n)FEATURE_V_1_3_ENUM_VALUE_DESCRIPTOR_PROTO\x10\xd5\x65\x1a\x02\x08\x01\x12%\n\x15\x46\x45\x41TURE_DECIMAL_ALIAS\x10\xd6\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12$\n\x1b\x46\x45\x41TURE_V_1_3_DECIMAL_ALIAS\x10\xd6\x65\x1a\x02\x08\x01\x12\x31\n!FEATURE_UNNEST_AND_FLATTEN_ARRAYS\x10\xd7\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x30\n\'FEATURE_V_1_3_UNNEST_AND_FLATTEN_ARRAYS\x10\xd7\x65\x1a\x02\x08\x01\x12,\n\x1c\x46\x45\x41TURE_ALLOW_CONSECUTIVE_ON\x10\xd8\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12+\n\"FEATURE_V_1_3_ALLOW_CONSECUTIVE_ON\x10\xd8\x65\x1a\x02\x08\x01\x12\x36\n&FEATURE_ALLOW_REGEXP_EXTRACT_OPTIONALS\x10\xd9\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x35\n,FEATURE_V_1_3_ALLOW_REGEXP_EXTRACT_OPTIONALS\x10\xd9\x65\x1a\x02\x08\x01\x12.\n\x1e\x46\x45\x41TURE_DATE_TIME_CONSTRUCTORS\x10\xda\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12-\n$FEATURE_V_1_3_DATE_TIME_CONSTRUCTORS\x10\xda\x65\x1a\x02\x08\x01\x12(\n\x18\x46\x45\x41TURE_DATE_ARITHMETICS\x10\xdb\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\'\n\x1e\x46\x45\x41TURE_V_1_3_DATE_ARITHMETICS\x10\xdb\x65\x1a\x02\x08\x01\x12\x33\n#FEATURE_ADDITIONAL_STRING_FUNCTIONS\x10\xdc\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x32\n)FEATURE_V_1_3_ADDITIONAL_STRING_FUNCTIONS\x10\xdc\x65\x1a\x02\x08\x01\x12+\n\x17\x46\x45\x41TURE_WITH_GROUP_ROWS\x10\xdd\x65\x1a\r\xda\xf1\xaa\x89\x05\x07\x08\x00\x10\x01\x18\xc8\x65\x12&\n\x1d\x46\x45\x41TURE_V_1_3_WITH_GROUP_ROWS\x10\xdd\x65\x1a\x02\x08\x01\x12\x35\n%FEATURE_EXTENDED_DATE_TIME_SIGNATURES\x10\xde\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x34\n+FEATURE_V_1_3_EXTENDED_DATE_TIME_SIGNATURES\x10\xde\x65\x1a\x02\x08\x01\x12\x32\n\"FEATURE_EXTENDED_GEOGRAPHY_PARSERS\x10\xdf\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x31\n(FEATURE_V_1_3_EXTENDED_GEOGRAPHY_PARSERS\x10\xdf\x65\x1a\x02\x08\x01\x12.\n\x1e\x46\x45\x41TURE_INLINE_LAMBDA_ARGUMENT\x10\xe0\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12-\n$FEATURE_V_1_3_INLINE_LAMBDA_ARGUMENT\x10\xe0\x65\x1a\x02\x08\x01\x12\x1d\n\rFEATURE_PIVOT\x10\xe1\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x1c\n\x13\x46\x45\x41TURE_V_1_3_PIVOT\x10\xe1\x65\x1a\x02\x08\x01\x12,\n\x1c\x46\x45\x41TURE_ANNOTATION_FRAMEWORK\x10\xe2\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12+\n\"FEATURE_V_1_3_ANNOTATION_FRAMEWORK\x10\xe2\x65\x1a\x02\x08\x01\x12+\n\x19\x46\x45\x41TURE_COLLATION_SUPPORT\x10\xe3\x65\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xc8\x65\x12(\n\x1f\x46\x45\x41TURE_V_1_3_COLLATION_SUPPORT\x10\xe3\x65\x1a\x02\x08\x01\x12#\n\x13\x46\x45\x41TURE_IS_DISTINCT\x10\xe4\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\"\n\x19\x46\x45\x41TURE_V_1_3_IS_DISTINCT\x10\xe4\x65\x1a\x02\x08\x01\x12&\n\x16\x46\x45\x41TURE_FORMAT_IN_CAST\x10\xe5\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12%\n\x1c\x46\x45\x41TURE_V_1_3_FORMAT_IN_CAST\x10\xe5\x65\x1a\x02\x08\x01\x12\x1f\n\x0f\x46\x45\x41TURE_UNPIVOT\x10\xe6\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x1e\n\x15\x46\x45\x41TURE_V_1_3_UNPIVOT\x10\xe6\x65\x1a\x02\x08\x01\x12%\n\x15\x46\x45\x41TURE_DML_RETURNING\x10\xe7\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12$\n\x1b\x46\x45\x41TURE_V_1_3_DML_RETURNING\x10\xe7\x65\x1a\x02\x08\x01\x12%\n\x15\x46\x45\x41TURE_FILTER_FIELDS\x10\xe8\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12$\n\x1b\x46\x45\x41TURE_V_1_3_FILTER_FIELDS\x10\xe8\x65\x1a\x02\x08\x01\x12\x1f\n\x0f\x46\x45\x41TURE_QUALIFY\x10\xe9\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x1e\n\x15\x46\x45\x41TURE_V_1_3_QUALIFY\x10\xe9\x65\x1a\x02\x08\x01\x12\x1e\n\x0e\x46\x45\x41TURE_REPEAT\x10\xea\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x1d\n\x14\x46\x45\x41TURE_V_1_3_REPEAT\x10\xea\x65\x1a\x02\x08\x01\x12,\n\x1c\x46\x45\x41TURE_COLUMN_DEFAULT_VALUE\x10\xeb\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12+\n\"FEATURE_V_1_3_COLUMN_DEFAULT_VALUE\x10\xeb\x65\x1a\x02\x08\x01\x12\x1e\n\x0e\x46\x45\x41TURE_FOR_IN\x10\xec\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x1d\n\x14\x46\x45\x41TURE_V_1_3_FOR_IN\x10\xec\x65\x1a\x02\x08\x01\x12#\n\x13\x46\x45\x41TURE_KLL_WEIGHTS\x10\xed\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\"\n\x19\x46\x45\x41TURE_V_1_3_KLL_WEIGHTS\x10\xed\x65\x1a\x02\x08\x01\x12)\n\x19\x46\x45\x41TURE_LIKE_ANY_SOME_ALL\x10\xee\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12(\n\x1f\x46\x45\x41TURE_V_1_3_LIKE_ANY_SOME_ALL\x10\xee\x65\x1a\x02\x08\x01\x12!\n\x11\x46\x45\x41TURE_CASE_STMT\x10\xef\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12 \n\x17\x46\x45\x41TURE_V_1_3_CASE_STMT\x10\xef\x65\x1a\x02\x08\x01\x12)\n\x19\x46\x45\x41TURE_ALLOW_SLASH_PATHS\x10\xf0\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12(\n\x1f\x46\x45\x41TURE_V_1_3_ALLOW_SLASH_PATHS\x10\xf0\x65\x1a\x02\x08\x01\x12\'\n\x17\x46\x45\x41TURE_TYPEOF_FUNCTION\x10\xf1\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12&\n\x1d\x46\x45\x41TURE_V_1_3_TYPEOF_FUNCTION\x10\xf1\x65\x1a\x02\x08\x01\x12$\n\x14\x46\x45\x41TURE_SCRIPT_LABEL\x10\xf2\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12#\n\x1a\x46\x45\x41TURE_V_1_3_SCRIPT_LABEL\x10\xf2\x65\x1a\x02\x08\x01\x12\'\n\x17\x46\x45\x41TURE_REMOTE_FUNCTION\x10\xf3\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12&\n\x1d\x46\x45\x41TURE_V_1_3_REMOTE_FUNCTION\x10\xf3\x65\x1a\x02\x08\x01\x12,\n\x1c\x46\x45\x41TURE_ARRAY_GREATEST_LEAST\x10\xf4\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12+\n\"FEATURE_V_1_3_ARRAY_GREATEST_LEAST\x10\xf4\x65\x1a\x02\x08\x01\x12\x31\n!FEATURE_BRACED_PROTO_CONSTRUCTORS\x10\xf5\x65\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xc8\x65\x12\x30\n\'FEATURE_V_1_3_BRACED_PROTO_CONSTRUCTORS\x10\xf5\x65\x1a\x02\x08\x01\x12\'\n\x17\x46\x45\x41TURE_WITH_EXPRESSION\x10\xb0m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12&\n\x1d\x46\x45\x41TURE_V_1_4_WITH_EXPRESSION\x10\xb0m\x1a\x02\x08\x01\x12.\n\x1c\x46\x45\x41TURE_ORDERED_PRIMARY_KEYS\x10\xb2m\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12+\n\"FEATURE_V_1_4_ORDERED_PRIMARY_KEYS\x10\xb2m\x1a\x02\x08\x01\x12\x1d\n\x0b\x46\x45\x41TURE_TTL\x10\xb3m\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x1a\n\x11\x46\x45\x41TURE_V_1_4_TTL\x10\xb3m\x1a\x02\x08\x01\x12)\n\x19\x46\x45\x41TURE_BARE_ARRAY_ACCESS\x10\xb4m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12(\n\x1f\x46\x45\x41TURE_V_1_4_BARE_ARRAY_ACCESS\x10\xb4m\x1a\x02\x08\x01\x12\x33\n#FEATURE_ARRAY_AGGREGATION_FUNCTIONS\x10\xb5m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x32\n)FEATURE_V_1_4_ARRAY_AGGREGATION_FUNCTIONS\x10\xb5m\x1a\x02\x08\x01\x12,\n\x1c\x46\x45\x41TURE_ARRAY_FIND_FUNCTIONS\x10\xb6m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12+\n\"FEATURE_V_1_4_ARRAY_FIND_FUNCTIONS\x10\xb6m\x1a\x02\x08\x01\x12;\n+FEATURE_SAFE_FUNCTION_CALL_WITH_LAMBDA_ARGS\x10\xb7m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12:\n1FEATURE_V_1_4_SAFE_FUNCTION_CALL_WITH_LAMBDA_ARGS\x10\xb7m\x1a\x02\x08\x01\x12!\n\x11\x46\x45\x41TURE_SQL_GRAPH\x10\xb8m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12 \n\x17\x46\x45\x41TURE_V_1_4_SQL_GRAPH\x10\xb8m\x1a\x02\x08\x01\x12\x30\n FEATURE_SQL_GRAPH_ADVANCED_QUERY\x10\xd4m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12/\n&FEATURE_V_1_4_SQL_GRAPH_ADVANCED_QUERY\x10\xd4m\x1a\x02\x08\x01\x12\x36\n&FEATURE_SQL_GRAPH_EXPOSE_GRAPH_ELEMENT\x10\xd9m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x35\n,FEATURE_V_1_4_SQL_GRAPH_EXPOSE_GRAPH_ELEMENT\x10\xd9m\x1a\x02\x08\x01\x12=\n-FEATURE_SQL_GRAPH_BOUNDED_PATH_QUANTIFICATION\x10\xebm\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12<\n3FEATURE_V_1_4_SQL_GRAPH_BOUNDED_PATH_QUANTIFICATION\x10\xebm\x1a\x02\x08\x01\x12\x41\n/FEATURE_SQL_GRAPH_UNBOUNDED_PATH_QUANTIFICATION\x10\x9bn\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x33\n#FEATURE_SQL_GRAPH_RETURN_EXTENSIONS\x10\xf5m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x32\n)FEATURE_V_1_4_SQL_GRAPH_RETURN_EXTENSIONS\x10\xf5m\x1a\x02\x08\x01\x12+\n\x1b\x46\x45\x41TURE_SQL_GRAPH_PATH_TYPE\x10\xeem\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12*\n!FEATURE_V_1_4_SQL_GRAPH_PATH_TYPE\x10\xeem\x1a\x02\x08\x01\x12+\n\x1b\x46\x45\x41TURE_GROUP_BY_GRAPH_PATH\x10\xf3m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12*\n!FEATURE_V_1_4_GROUP_BY_GRAPH_PATH\x10\xf3m\x1a\x02\x08\x01\x12?\n/FEATURE_SQL_GRAPH_PATH_SEARCH_PREFIX_PATH_COUNT\x10\x8cn\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12>\n5FEATURE_V_1_4_SQL_GRAPH_PATH_SEARCH_PREFIX_PATH_COUNT\x10\x8cn\x1a\x02\x08\x01\x12+\n\x1b\x46\x45\x41TURE_SQL_GRAPH_PATH_MODE\x10\xefm\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12*\n!FEATURE_V_1_4_SQL_GRAPH_PATH_MODE\x10\xefm\x1a\x02\x08\x01\x12\x36\n&FEATURE_SQL_GRAPH_DYNAMIC_ELEMENT_TYPE\x10\xf8m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x35\n,FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_ELEMENT_TYPE\x10\xf8m\x1a\x02\x08\x01\x12\x41\n1FEATURE_SQL_GRAPH_DYNAMIC_LABEL_PROPERTIES_IN_DDL\x10\xfem\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12@\n7FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_LABEL_PROPERTIES_IN_DDL\x10\xfem\x1a\x02\x08\x01\x12@\n0FEATURE_SQL_GRAPH_DYNAMIC_LABEL_EXTENSION_IN_DDL\x10\x8fn\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12?\n6FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_LABEL_EXTENSION_IN_DDL\x10\x8fn\x1a\x02\x08\x01\x12=\n+FEATURE_SQL_GRAPH_DYNAMIC_MULTI_LABEL_NODES\x10\x93n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12:\n1FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_MULTI_LABEL_NODES\x10\x93n\x1a\x02\x08\x01\x12J\n8FEATURE_SQL_GRAPH_ELEMENT_DEFINITION_NAME_IN_JSON_RESULT\x10\x87n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12G\n>FEATURE_V_1_4_SQL_GRAPH_ELEMENT_DEFINITION_NAME_IN_JSON_RESULT\x10\x87n\x1a\x02\x08\x01\x12/\n\x1f\x46\x45\x41TURE_SQL_GRAPH_CHEAPEST_PATH\x10\x8bn\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12.\n%FEATURE_V_1_4_SQL_GRAPH_CHEAPEST_PATH\x10\x8bn\x1a\x02\x08\x01\x12&\n\x16\x46\x45\x41TURE_SQL_GRAPH_CALL\x10\x94n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12%\n\x1c\x46\x45\x41TURE_V_1_4_SQL_GRAPH_CALL\x10\x94n\x1a\x02\x08\x01\x12\x42\n0FEATURE_SQL_GRAPH_SET_OPERATION_PROPAGATION_MODE\x10\xa8n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12Q\n?FEATURE_SQL_GRAPH_DEFAULT_LABEL_AND_PROPERTY_DEFINITION_OPTIONS\x10\xa9n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12$\n\x14\x46\x45\x41TURE_REMOTE_MODEL\x10\xb9m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12#\n\x1a\x46\x45\x41TURE_V_1_4_REMOTE_MODEL\x10\xb9m\x1a\x02\x08\x01\x12\x32\n\"FEATURE_STRUCT_POSITIONAL_ACCESSOR\x10\xbam\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x31\n(FEATURE_V_1_4_STRUCT_POSITIONAL_ACCESSOR\x10\xbam\x1a\x02\x08\x01\x12\x34\n$FEATURE_SINGLE_TABLE_NAME_ARRAY_PATH\x10\xbbm\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x33\n*FEATURE_V_1_4_SINGLE_TABLE_NAME_ARRAY_PATH\x10\xbbm\x1a\x02\x08\x01\x12\x35\n#FEATURE_COLLATION_IN_WITH_RECURSIVE\x10\xbdm\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x32\n)FEATURE_V_1_4_COLLATION_IN_WITH_RECURSIVE\x10\xbdm\x1a\x02\x08\x01\x12\x34\n\"FEATURE_COLLATION_IN_EXPLICIT_CAST\x10\xbem\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x31\n(FEATURE_V_1_4_COLLATION_IN_EXPLICIT_CAST\x10\xbem\x1a\x02\x08\x01\x12,\n\x1c\x46\x45\x41TURE_LOAD_DATA_PARTITIONS\x10\xbfm\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12+\n\"FEATURE_V_1_4_LOAD_DATA_PARTITIONS\x10\xbfm\x1a\x02\x08\x01\x12<\n,FEATURE_CREATE_MODEL_WITH_ALIASED_QUERY_LIST\x10\xc0m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12;\n2FEATURE_V_1_4_CREATE_MODEL_WITH_ALIASED_QUERY_LIST\x10\xc0m\x1a\x02\x08\x01\x12,\n\x1c\x46\x45\x41TURE_LOAD_DATA_TEMP_TABLE\x10\xc1m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12+\n\"FEATURE_V_1_4_LOAD_DATA_TEMP_TABLE\x10\xc1m\x1a\x02\x08\x01\x12%\n\x15\x46\x45\x41TURE_CORRESPONDING\x10\xc2m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12$\n\x1b\x46\x45\x41TURE_V_1_4_CORRESPONDING\x10\xc2m\x1a\x02\x08\x01\x12&\n\x14\x46\x45\x41TURE_SEQUENCE_ARG\x10\xc3m\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12#\n\x1a\x46\x45\x41TURE_V_1_4_SEQUENCE_ARG\x10\xc3m\x1a\x02\x08\x01\x12(\n\x18\x46\x45\x41TURE_GROUPING_BUILTIN\x10\xc4m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\'\n\x1e\x46\x45\x41TURE_V_1_4_GROUPING_BUILTIN\x10\xc4m\x1a\x02\x08\x01\x12%\n\x15\x46\x45\x41TURE_GROUPING_SETS\x10\xc5m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12$\n\x1b\x46\x45\x41TURE_V_1_4_GROUPING_SETS\x10\xc5m\x1a\x02\x08\x01\x12\x46\n4FEATURE_PRESERVE_ANNOTATION_IN_IMPLICIT_CAST_IN_SCAN\x10\xc6m\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x43\n:FEATURE_V_1_4_PRESERVE_ANNOTATION_IN_IMPLICIT_CAST_IN_SCAN\x10\xc6m\x1a\x02\x08\x01\x12*\n\x1a\x46\x45\x41TURE_CORRESPONDING_FULL\x10\xc7m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12)\n FEATURE_V_1_4_CORRESPONDING_FULL\x10\xc7m\x1a\x02\x08\x01\x12\x1f\n\x0f\x46\x45\x41TURE_BY_NAME\x10\xf6m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x1e\n\x15\x46\x45\x41TURE_V_1_4_BY_NAME\x10\xf6m\x1a\x02\x08\x01\x12\x31\n\x1f\x46\x45\x41TURE_LIKE_ANY_SOME_ALL_ARRAY\x10\xc9m\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12.\n%FEATURE_V_1_4_LIKE_ANY_SOME_ALL_ARRAY\x10\xc9m\x1a\x02\x08\x01\x12\x34\n\"FEATURE_LIKE_ANY_SOME_ALL_SUBQUERY\x10\xcam\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x31\n(FEATURE_V_1_4_LIKE_ANY_SOME_ALL_SUBQUERY\x10\xcam\x1a\x02\x08\x01\x12(\n\x18\x46\x45\x41TURE_FIRST_AND_LAST_N\x10\xcbm\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\'\n\x1e\x46\x45\x41TURE_V_1_4_FIRST_AND_LAST_N\x10\xcbm\x1a\x02\x08\x01\x12-\n\x1d\x46\x45\x41TURE_NULLIFZERO_ZEROIFNULL\x10\xccm\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12,\n#FEATURE_V_1_4_NULLIFZERO_ZEROIFNULL\x10\xccm\x1a\x02\x08\x01\x12$\n\x14\x46\x45\x41TURE_PI_FUNCTIONS\x10\xcdm\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12#\n\x1a\x46\x45\x41TURE_V_1_4_PI_FUNCTIONS\x10\xcdm\x1a\x02\x08\x01\x12@\n0FEATURE_CREATE_FUNCTION_LANGUAGE_WITH_CONNECTION\x10\xcem\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12?\n6FEATURE_V_1_4_CREATE_FUNCTION_LANGUAGE_WITH_CONNECTION\x10\xcem\x1a\x02\x08\x01\x12\x37\n%FEATURE_SINGLETON_UNNEST_INFERS_ALIAS\x10\xcfm\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x34\n+FEATURE_V_1_4_SINGLETON_UNNEST_INFERS_ALIAS\x10\xcfm\x1a\x02\x08\x01\x12!\n\x11\x46\x45\x41TURE_ARRAY_ZIP\x10\xd0m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12 \n\x17\x46\x45\x41TURE_V_1_4_ARRAY_ZIP\x10\xd0m\x1a\x02\x08\x01\x12\'\n\x17\x46\x45\x41TURE_MULTIWAY_UNNEST\x10\xd1m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12&\n\x1d\x46\x45\x41TURE_V_1_4_MULTIWAY_UNNEST\x10\xd1m\x1a\x02\x08\x01\x12<\n*FEATURE_USE_OPERATION_COLLATION_FOR_NULLIF\x10\xd2m\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x39\n0FEATURE_V_1_4_USE_OPERATION_COLLATION_FOR_NULLIF\x10\xd2m\x1a\x02\x08\x01\x12\x34\n\"FEATURE_ENABLE_EDIT_DISTANCE_BYTES\x10\xd3m\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x31\n(FEATURE_V_1_4_ENABLE_EDIT_DISTANCE_BYTES\x10\xd3m\x1a\x02\x08\x01\x12\x37\n\'FEATURE_ENABLE_FLOAT_DISTANCE_FUNCTIONS\x10\xd5m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x36\n-FEATURE_V_1_4_ENABLE_FLOAT_DISTANCE_FUNCTIONS\x10\xd5m\x1a\x02\x08\x01\x12\'\n\x17\x46\x45\x41TURE_ENABLE_MEASURES\x10\xd6m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12&\n\x1d\x46\x45\x41TURE_V_1_4_ENABLE_MEASURES\x10\xd6m\x1a\x02\x08\x01\x12$\n\x14\x46\x45\x41TURE_GROUP_BY_ALL\x10\xd7m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12#\n\x1a\x46\x45\x41TURE_V_1_4_GROUP_BY_ALL\x10\xd7m\x1a\x02\x08\x01\x12\x30\n FEATURE_LIMIT_OFFSET_EXPRESSIONS\x10\xdam\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12/\n&FEATURE_V_1_4_LIMIT_OFFSET_EXPRESSIONS\x10\xdam\x1a\x02\x08\x01\x12\"\n\x10\x46\x45\x41TURE_MAP_TYPE\x10\xdbm\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x1f\n\x16\x46\x45\x41TURE_V_1_4_MAP_TYPE\x10\xdbm\x1a\x02\x08\x01\x12+\n\x17\x46\x45\x41TURE_DISABLE_FLOAT32\x10\xdcm\x1a\r\xda\xf1\xaa\x89\x05\x07\x08\x00\x10\x01\x18\xb0m\x12&\n\x1d\x46\x45\x41TURE_V_1_4_DISABLE_FLOAT32\x10\xdcm\x1a\x02\x08\x01\x12-\n\x1d\x46\x45\x41TURE_LITERAL_CONCATENATION\x10\xddm\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12,\n#FEATURE_V_1_4_LITERAL_CONCATENATION\x10\xddm\x1a\x02\x08\x01\x12#\n\x13\x46\x45\x41TURE_DOT_PRODUCT\x10\xdem\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\"\n\x19\x46\x45\x41TURE_V_1_4_DOT_PRODUCT\x10\xdem\x1a\x02\x08\x01\x12\x43\n1FEATURE_OPT_IN_NEW_BEHAVIOR_NOT_LIKE_ANY_SOME_ALL\x10\xdfm\x1a\x0b\x08\x01\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12@\n7FEATURE_V_1_4_OPT_IN_NEW_BEHAVIOR_NOT_LIKE_ANY_SOME_ALL\x10\xdfm\x1a\x02\x08\x01\x12*\n\x1a\x46\x45\x41TURE_MANHATTAN_DISTANCE\x10\xe0m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12)\n FEATURE_V_1_4_MANHATTAN_DISTANCE\x10\xe0m\x1a\x02\x08\x01\x12\x1f\n\x0f\x46\x45\x41TURE_L1_NORM\x10\xe1m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x1e\n\x15\x46\x45\x41TURE_V_1_4_L1_NORM\x10\xe1m\x1a\x02\x08\x01\x12\x1f\n\x0f\x46\x45\x41TURE_L2_NORM\x10\xe2m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x1e\n\x15\x46\x45\x41TURE_V_1_4_L2_NORM\x10\xe2m\x1a\x02\x08\x01\x12\x34\n\"FEATURE_STRUCT_BRACED_CONSTRUCTORS\x10\xe3m\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x31\n(FEATURE_V_1_4_STRUCT_BRACED_CONSTRUCTORS\x10\xe3m\x1a\x02\x08\x01\x12\x35\n%FEATURE_WITH_RECURSIVE_DEPTH_MODIFIER\x10\xe4m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x34\n+FEATURE_V_1_4_WITH_RECURSIVE_DEPTH_MODIFIER\x10\xe4m\x1a\x02\x08\x01\x12=\n-FEATURE_JSON_ARRAY_VALUE_EXTRACTION_FUNCTIONS\x10\xe5m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12<\n3FEATURE_V_1_4_JSON_ARRAY_VALUE_EXTRACTION_FUNCTIONS\x10\xe5m\x1a\x02\x08\x01\x12\x38\n&FEATURE_ENFORCE_CONDITIONAL_EVALUATION\x10\xe6m\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x35\n,FEATURE_V_1_4_ENFORCE_CONDITIONAL_EVALUATION\x10\xe6m\x1a\x02\x08\x01\x12<\n,FEATURE_JSON_MORE_VALUE_EXTRACTION_FUNCTIONS\x10\xe7m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12;\n2FEATURE_V_1_4_JSON_MORE_VALUE_EXTRACTION_FUNCTIONS\x10\xe7m\x1a\x02\x08\x01\x12\x41\n1FEATURE_IMPLICIT_COERCION_STRING_LITERAL_TO_BYTES\x10\xe8m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12@\n7FEATURE_V_1_4_IMPLICIT_COERCION_STRING_LITERAL_TO_BYTES\x10\xe8m\x1a\x02\x08\x01\x12!\n\x11\x46\x45\x41TURE_UUID_TYPE\x10\xe9m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12 \n\x17\x46\x45\x41TURE_V_1_4_UUID_TYPE\x10\xe9m\x1a\x02\x08\x01\x12.\n\x1e\x46\x45\x41TURE_MULTILEVEL_AGGREGATION\x10\xeam\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12-\n$FEATURE_V_1_4_MULTILEVEL_AGGREGATION\x10\xeam\x1a\x02\x08\x01\x12+\n\x1b\x46\x45\x41TURE_AGGREGATE_FILTERING\x10\xf9m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12*\n!FEATURE_V_1_4_AGGREGATE_FILTERING\x10\xf9m\x1a\x02\x08\x01\x12\x38\n(FEATURE_REPLACE_FIELDS_ALLOW_MULTI_ONEOF\x10\xecm\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x37\n.FEATURE_V_1_4_REPLACE_FIELDS_ALLOW_MULTI_ONEOF\x10\xecm\x1a\x02\x08\x01\x12\"\n\x12\x46\x45\x41TURE_FOR_UPDATE\x10\xf1m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12!\n\x18\x46\x45\x41TURE_V_1_4_FOR_UPDATE\x10\xf1m\x1a\x02\x08\x01\x12=\n-FEATURE_KLL_FLOAT64_PRIMARY_WITH_DOUBLE_ALIAS\x10\xf0m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12<\n3FEATURE_V_1_4_KLL_FLOAT64_PRIMARY_WITH_DOUBLE_ALIAS\x10\xf0m\x1a\x02\x08\x01\x12\x41\n1FEATURE_DISALLOW_PIVOT_AND_UNPIVOT_ON_ARRAY_SCANS\x10\xf2m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12@\n7FEATURE_V_1_4_DISALLOW_PIVOT_AND_UNPIVOT_ON_ARRAY_SCANS\x10\xf2m\x1a\x02\x08\x01\x12\'\n\x17\x46\x45\x41TURE_MATCH_RECOGNIZE\x10\xf4m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12&\n\x1d\x46\x45\x41TURE_V_1_4_MATCH_RECOGNIZE\x10\xf4m\x1a\x02\x08\x01\x12\x31\n!FEATURE_INSERT_ON_CONFLICT_CLAUSE\x10\xf7m\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x30\n\'FEATURE_V_1_4_INSERT_ON_CONFLICT_CLAUSE\x10\xf7m\x1a\x02\x08\x01\x12:\n*FEATURE_BITWISE_AGGREGATE_BYTES_SIGNATURES\x10\xfam\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x39\n0FEATURE_V_1_4_BITWISE_AGGREGATE_BYTES_SIGNATURES\x10\xfam\x1a\x02\x08\x01\x12,\n\x1c\x46\x45\x41TURE_PIPE_RECURSIVE_UNION\x10\xfbm\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12+\n\"FEATURE_V_1_4_PIPE_RECURSIVE_UNION\x10\xfbm\x1a\x02\x08\x01\x12,\n\x1a\x46\x45\x41TURE_UPDATE_CONSTRUCTOR\x10\xffm\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12)\n FEATURE_V_1_4_UPDATE_CONSTRUCTOR\x10\xffm\x1a\x02\x08\x01\x12?\n-FEATURE_ALIASES_FOR_STRING_AND_DATE_FUNCTIONS\x10\x80n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12<\n3FEATURE_V_1_4_ALIASES_FOR_STRING_AND_DATE_FUNCTIONS\x10\x80n\x1a\x02\x08\x01\x12*\n\x18\x46\x45\x41TURE_VIEWS_IN_MODULES\x10\x81n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\'\n\x1e\x46\x45\x41TURE_V_1_4_VIEWS_IN_MODULES\x10\x81n\x1a\x02\x08\x01\x12+\n&FEATURE_MULTILEVEL_AGGREGATION_ON_UDAS\x10\x8f\x01\x12\x32\n\"FEATURE_FROM_AND_TO_PROTO_INTERVAL\x10\x83n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x31\n(FEATURE_V_1_4_FROM_AND_TO_PROTO_INTERVAL\x10\x83n\x1a\x02\x08\x01\x12.\n\x1e\x46\x45\x41TURE_SIMPLIFY_PIVOT_REWRITE\x10\x84n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12-\n$FEATURE_V_1_4_SIMPLIFY_PIVOT_REWRITE\x10\x84n\x1a\x02\x08\x01\x12*\n\x1a\x46\x45\x41TURE_PIPE_NAMED_WINDOWS\x10\x86n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12)\n FEATURE_V_1_4_PIPE_NAMED_WINDOWS\x10\x86n\x1a\x02\x08\x01\x12,\n\x1a\x46\x45\x41TURE_TVF_PSEUDO_COLUMNS\x10\x88n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12)\n FEATURE_V_1_4_TVF_PSEUDO_COLUMNS\x10\x88n\x1a\x02\x08\x01\x12$\n\x14\x46\x45\x41TURE_LATERAL_JOIN\x10\x89n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12#\n\x1a\x46\x45\x41TURE_V_1_4_LATERAL_JOIN\x10\x89n\x1a\x02\x08\x01\x12.\n\x1e\x46\x45\x41TURE_CHAINED_FUNCTION_CALLS\x10\x8an\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12-\n$FEATURE_V_1_4_CHAINED_FUNCTION_CALLS\x10\x8an\x1a\x02\x08\x01\x12+\n\x1b\x46\x45\x41TURE_TIMESTAMP_PRECISION\x10\x8dn\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12*\n!FEATURE_V_1_4_TIMESTAMP_PRECISION\x10\x8dn\x1a\x02\x08\x01\x12\x38\n&FEATURE_TIMESTAMP_PRECISION_ANNOTATION\x10\x90n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x35\n,FEATURE_V_1_4_TIMESTAMP_PRECISION_ANNOTATION\x10\x90n\x1a\x02\x08\x01\x12\x46\n4FEATURE_ANALYSIS_CONSTANT_STRUCT_POSITIONAL_ACCESSOR\x10\x8en\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x43\n:FEATURE_V_1_4_ANALYSIS_CONSTANT_STRUCT_POSITIONAL_ACCESSOR\x10\x8en\x1a\x02\x08\x01\x12=\n+FEATURE_ANALYSIS_CONSTANT_FUNCTION_ARGUMENT\x10\x97n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x38\n&FEATURE_ANALYSIS_CONSTANT_PIVOT_COLUMN\x10\x96n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12@\n.FEATURE_ANALYSIS_CONSTANT_INTERVAL_CONSTRUCTOR\x10\x98n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x39\n\'FEATURE_REPORT_FORMAT_CONSTANT_ARGUMENT\x10\x9cn\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12%\n\x15\x46\x45\x41TURE_PIPE_DESCRIBE\x10\x92n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12+\n\x1b\x46\x45\x41TURE_MULTI_GROUPING_SETS\x10\x95n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12-\n\x1d\x46\x45\x41TURE_PIPE_CALL_INPUT_TABLE\x10\x99n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x30\n\x1e\x46\x45\x41TURE_RELAXED_WITH_RECURSIVE\x10\x9an\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\'\n\x15\x46\x45\x41TURE_RUN_STATEMENT\x10\x9en\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12#\n\x11\x46\x45\x41TURE_LIMIT_ALL\x10\xa1n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\x38\n&FEATURE_ADDITIONAL_DATE_TIME_FUNCTIONS\x10\xa2n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12;\n+FEATURE_KLL_QUANTILES_EXTRACT_RELATIVE_RANK\x10\xa3n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x35\n%FEATURE_MATCH_MAKE_STRUCT_IN_GROUP_BY\x10\xa4n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12R\nBFEATURE_ARRAY_CONSTRUCTOR_EXPLICIT_TYPE_ENFORCE_TARGET_ANNOTATIONS\x10\xa5n\x1a\t\xda\xf1\xaa\x89\x05\x03\x18\xb0m\x12\x32\n!FEATURE_LATERAL_COLUMN_REFERENCES\x10\xa6n\x1a\n\xda\xf1\xaa\x89\x05\x04\x08\x00\x10\x01\x12\"\n\x10\x46\x45\x41TURE_ROW_TYPE\x10\xa7n\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12&\n\x14\x46\x45\x41TURE_MEASURES_TVF\x10\xaan\x1a\x0b\xda\xf1\xaa\x89\x05\x05\x10\x01\x18\xb0m\x12\"\n\x1c\x46\x45\x41TURE_EXPERIMENTAL_MODULES\x10\xda\xfc<\x12?\n/FEATURE_TEST_IDEALLY_ENABLED_BUT_IN_DEVELOPMENT\x10\xb7\x84=\x1a\x08\xda\xf1\xaa\x89\x05\x02\x10\x01\x12-\n\x1d\x46\x45\x41TURE_TEST_IDEALLY_DISABLED\x10\xb8\x84=\x1a\x08\xda\xf1\xaa\x89\x05\x02\x08\x00\x12\x42\n0FEATURE_TEST_IDEALLY_DISABLED_AND_IN_DEVELOPMENT\x10\xb9\x84=\x1a\n\xda\xf1\xaa\x89\x05\x04\x08\x00\x10\x01\x12<\n/__LanguageFeature__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x1a\x02\x10\x01\"\x04\x08\x04\x10\x04\"\x04\x08$\x10\'\"\x04\x08,\x10.\"\x04\x08\x30\x10\x30\"\x04\x08\x36\x10\x36\"\x04\x08\x37\x10\x37\"\x04\x08J\x10J\"\x04\x08\x63\x10\x63\"\x04\x08l\x10l\"\x04\x08n\x10n\"\x04\x08|\x10|\"\x06\x08\x84\x01\x10\x84\x01\"\x06\x08\x8c\x01\x10\x8c\x01\"\x06\x08\xf6\x65\x10\xf6\x65\"\x06\x08\xb1m\x10\xb1m\"\x06\x08\xbcm\x10\xbcm\"\x06\x08\xc8m\x10\xc8m\"\x06\x08\xd8m\x10\xd8m\"\x06\x08\xedm\x10\xedm\"\x06\x08\xfdm\x10\xfdm\"\x06\x08\x82n\x10\x82n\"\x06\x08\x85n\x10\x85n\"\x08\x08\xdb\xfc<\x10\xdb\xfc<\"\x08\x08\xdc\xfc<\x10\xdc\xfc<\"\x08\x08\xdd\xfc<\x10\xdd\xfc<*\xfb\x0c\n\x12ResolvedASTRewrite\x12\x1e\n\x1aREWRITE_INVALID_DO_NOT_USE\x10\x00\x12\x1d\n\x0fREWRITE_FLATTEN\x10\x01\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12#\n\x15REWRITE_ANONYMIZATION\x10\x02\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x00\x12#\n\x15REWRITE_PROTO_MAP_FNS\x10\x03\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12&\n\x1eREWRITE_ARRAY_FILTER_TRANSFORM\x10\x04\x1a\x02\x08\x01\x12\x1d\n\x0fREWRITE_UNPIVOT\x10\x05\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12\x1b\n\rREWRITE_PIVOT\x10\x06\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12\x1e\n\x16REWRITE_ARRAY_INCLUDES\x10\x07\x1a\x02\x08\x01\x12%\n\x17REWRITE_TYPEOF_FUNCTION\x10\x08\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12\x1f\n\x11REWRITE_WITH_EXPR\x10\t\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12*\n\x1cREWRITE_INLINE_SQL_FUNCTIONS\x10\n\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x00\x12\'\n\x17REWRITE_INLINE_SQL_TVFS\x10\x0b\x1a\n\x82\x87\xdd\x84\n\x04\x08\x00\x10\x01\x12*\n\x1cREWRITE_NULLIFERROR_FUNCTION\x10\x0c\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12\"\n\x14REWRITE_LIKE_ANY_ALL\x10\x0e\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12.\n REWRITE_BUILTIN_FUNCTION_INLINER\x10\x10\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12(\n\x18REWRITE_INLINE_SQL_VIEWS\x10\x11\x1a\n\x82\x87\xdd\x84\n\x04\x08\x01\x10\x01\x12%\n\x17REWRITE_INLINE_SQL_UDAS\x10\x16\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x00\x12$\n\x14REWRITE_GROUPING_SET\x10\x17\x1a\n\x82\x87\xdd\x84\n\x04\x08\x01\x10\x01\x12\'\n\x19REWRITE_INSERT_DML_VALUES\x10\x18\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x00\x12\'\n\x17REWRITE_MULTIWAY_UNNEST\x10\x19\x1a\n\x82\x87\xdd\x84\n\x04\x08\x00\x10\x01\x12+\n\x1dREWRITE_AGGREGATION_THRESHOLD\x10\x1a\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x00\x12#\n\x13REWRITE_PIPE_ASSERT\x10\x1b\x1a\n\x82\x87\xdd\x84\n\x04\x08\x00\x10\x01\x12\x35\n\'REWRITE_ORDER_BY_AND_LIMIT_IN_AGGREGATE\x10\x1c\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x00\x12\x1d\n\x0fREWRITE_PIPE_IF\x10\x1d\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12,\n\x1eREWRITE_GENERALIZED_QUERY_STMT\x10\x1f\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12\x31\n!REWRITE_IS_FIRST_IS_LAST_FUNCTION\x10 \x1a\n\x82\x87\xdd\x84\n\x04\x08\x00\x10\x01\x12\x30\n REWRITE_MATCH_RECOGNIZE_FUNCTION\x10%\x1a\n\x82\x87\xdd\x84\n\x04\x08\x00\x10\x01\x12\"\n\x14REWRITE_MEASURE_TYPE\x10\"\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x00\x12H\n:REWRITE_APPLY_ENABLED_REWRITES_TO_TEMPLATED_FUNCTION_CALLS\x10#\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x00\x12*\n\x1aREWRITE_UPDATE_CONSTRUCTOR\x10$\x1a\n\x82\x87\xdd\x84\n\x04\x08\x01\x10\x01\x12#\n\x15REWRITE_PIPE_DESCRIBE\x10&\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12&\n\x18REWRITE_SUBPIPELINE_STMT\x10\'\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12\x1e\n\x10REWRITE_ROW_TYPE\x10(\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12:\n,REWRITE_VARIADIC_FUNCTION_SIGNATURE_EXPANDER\x10)\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12-\n\x1dREWRITE_TEST_DEFAULT_DISABLED\x10\xb7\x84=\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x00\x12,\n\x1cREWRITE_TEST_DEFAULT_ENABLED\x10\xb8\x84=\x1a\x08\x82\x87\xdd\x84\n\x02\x08\x01\x12\x42\n0REWRITE_TEST_DEFAULT_DISABLED_AND_IN_DEVELOPMENT\x10\xb9\x84=\x1a\n\x82\x87\xdd\x84\n\x04\x08\x00\x10\x01\x12\x41\n/REWRITE_TEST_DEFAULT_ENABLED_AND_IN_DEVELOPMENT\x10\xba\x84=\x1a\n\x82\x87\xdd\x84\n\x04\x08\x01\x10\x01\"\x04\x08\r\x10\r\"\x04\x08\x0f\x10\x0f\"\x04\x08\x15\x10\x15*M\n\x12NameResolutionMode\x12\x1b\n\x17NAME_RESOLUTION_DEFAULT\x10\x00\x12\x1a\n\x16NAME_RESOLUTION_STRICT\x10\x01*9\n\x0bProductMode\x12\x14\n\x10PRODUCT_INTERNAL\x10\x00\x12\x14\n\x10PRODUCT_EXTERNAL\x10\x01*;\n\x10StatementContext\x12\x13\n\x0f\x43ONTEXT_DEFAULT\x10\x00\x12\x12\n\x0e\x43ONTEXT_MODULE\x10\x01*w\n\x10\x45rrorMessageMode\x12\x1e\n\x1a\x45RROR_MESSAGE_WITH_PAYLOAD\x10\x00\x12\x1a\n\x16\x45RROR_MESSAGE_ONE_LINE\x10\x01\x12\'\n#ERROR_MESSAGE_MULTI_LINE_WITH_CARET\x10\x02*\xb2\x02\n\x15\x45rrorMessageStability\x12\'\n#ERROR_MESSAGE_STABILITY_UNSPECIFIED\x10\x00\x12&\n\"ERROR_MESSAGE_STABILITY_PRODUCTION\x10\x01\x12)\n%ERROR_MESSAGE_STABILITY_TEST_REDACTED\x10\x02\x12\x37\n3ERROR_MESSAGE_STABILITY_TEST_REDACTED_WITH_PAYLOADS\x10\x03\x12*\n&ERROR_MESSAGE_STABILITY_TEST_MINIMIZED\x10\x04\x12\x38\n4ERROR_MESSAGE_STABILITY_TEST_MINIMIZED_WITH_PAYLOADS\x10\x05*R\n\rParameterMode\x12\x13\n\x0fPARAMETER_NAMED\x10\x00\x12\x18\n\x14PARAMETER_POSITIONAL\x10\x01\x12\x12\n\x0ePARAMETER_NONE\x10\x02*\x8b\x01\n\x17ParseLocationRecordType\x12\x1e\n\x1aPARSE_LOCATION_RECORD_NONE\x10\x00\x12)\n%PARSE_LOCATION_RECORD_FULL_NODE_SCOPE\x10\x01\x12%\n!PARSE_LOCATION_RECORD_CODE_SEARCH\x10\x02:g\n\x18language_feature_options\x12!.google.protobuf.EnumValueOptions\x18\x9b\xae\x95Q \x01(\x0b\x32\x1f.zetasql.LanguageFeatureOptions:b\n\x0frewrite_options\x12!.google.protobuf.EnumValueOptions\x18\xf0\xd0\xcb\xa0\x01 \x01(\x0b\x32\".zetasql.ResolvedASTRewriteOptionsB$\n\x12\x63om.google.zetasqlB\x0eZetaSQLOptions')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\016ZetaSQLOptions'
  _globals['_LANGUAGEFEATURE']._loaded_options = None
  _globals['_LANGUAGEFEATURE']._serialized_options = b'\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISALLOW_GROUP_BY_FLOAT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISALLOW_GROUP_BY_FLOAT"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PARSE_TIMESTAMP_WITH_PRECISION_AND_TIMEZONE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PARSE_TIMESTAMP_WITH_PRECISION_AND_TIMEZONE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISALLOW_NULL_PRIMARY_KEYS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISALLOW_NULL_PRIMARY_KEYS"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISALLOW_PRIMARY_KEY_UPDATES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISALLOW_PRIMARY_KEY_UPDATES"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANONYMIZATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANONYMIZATION"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANONYMIZATION_THRESHOLDING"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANONYMIZATION_THRESHOLDING"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANONYMIZATION_CASE_INSENSITIVE_OPTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANONYMIZATION_CASE_INSENSITIVE_OPTIONS"]._serialized_options = b'\332\361\252\211\005\002\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_REPORT_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_REPORT_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_THRESHOLDING"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_THRESHOLDING"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_MAX_ROWS_CONTRIBUTED"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_MAX_ROWS_CONTRIBUTED"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_PUBLIC_GROUPS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_PUBLIC_GROUPS"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_MIN_PRIVACY_UNITS_PER_GROUP"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_MIN_PRIVACY_UNITS_PER_GROUP"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_VECTOR_SEARCH_TVF"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_VECTOR_SEARCH_TVF"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_PER_AGGREGATION_BUDGET"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_PER_AGGREGATION_BUDGET"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_NESTED"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DIFFERENTIAL_PRIVACY_NESTED"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TUMBLE_HOP_TVFS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TUMBLE_HOP_TVFS"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TUMBLE_HOP_TVFS_NO_TIMESTAMP_COL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TUMBLE_HOP_TVFS_NO_TIMESTAMP_COL"]._serialized_options = b'\332\361\252\211\005\004\010\000\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LEGACY_BINARY_CONCAT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LEGACY_BINARY_CONCAT"]._serialized_options = b'\332\361\252\211\005\004\010\000\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_JSON_STRICT_NUMBER_PARSING"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_JSON_STRICT_NUMBER_PARSING"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_EXTERNAL_TABLE_WITH_PARTITION_COLUMNS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_EXTERNAL_TABLE_WITH_PARTITION_COLUMNS"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALTER_MATERIALIZED_VIEW_ALTER_COLUMN_SET_OPTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALTER_MATERIALIZED_VIEW_ALTER_COLUMN_SET_OPTIONS"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_TABLE_CLONE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_TABLE_CLONE"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CLONE_DATA"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CLONE_DATA"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALTER_COLUMN_SET_DATA_TYPE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALTER_COLUMN_SET_DATA_TYPE"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISALLOW_LEGACY_UNICODE_COLLATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISALLOW_LEGACY_UNICODE_COLLATION"]._serialized_options = b'\332\361\252\211\005\004\010\000\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_INVERSE_TRIG_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_INVERSE_TRIG_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NON_SQL_PROCEDURE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NON_SQL_PROCEDURE"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_RADIANS_DEGREES_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_RADIANS_DEGREES_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SPANNER_LEGACY_DDL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SPANNER_LEGACY_DDL"]._serialized_options = b'\332\361\252\211\005\004\010\000\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_ARRAY_MIN_AND_MAX"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_ARRAY_MIN_AND_MAX"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_STRICT_FUNCTION_DEFAULT_ARG_TYPE_COERCION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_STRICT_FUNCTION_DEFAULT_ARG_TYPE_COERCION"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROTO_BASE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROTO_BASE"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_ARRAY_SUM_AND_AVG"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_ARRAY_SUM_AND_AVG"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_VIEWS_WITH_COLUMN_OPTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_VIEWS_WITH_COLUMN_OPTIONS"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_OUTER_JOIN_ARRAY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_OUTER_JOIN_ARRAY"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_EXTERNAL_SECURITY_PROCEDURE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_EXTERNAL_SECURITY_PROCEDURE"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_LOCALITY_GROUP"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_LOCALITY_GROUP"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENABLE_ALTER_ARRAY_OPTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENABLE_ALTER_ARRAY_OPTIONS"]._serialized_options = b'\332\361\252\211\005\004\010\000\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_LOG"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_LOG"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_AGGREGATE_WITH_DIFFERENTIAL_PRIVACY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_AGGREGATE_WITH_DIFFERENTIAL_PRIVACY"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_TEXTMAPPER_PARSER"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_TEXTMAPPER_PARSER"]._serialized_options = b'\010\001\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_INDEX_PARTITION_BY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_INDEX_PARTITION_BY"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TO_JSON_UNSUPPORTED_FIELDS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TO_JSON_UNSUPPORTED_FIELDS"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROPERTY_GRAPH_ENFORCE_EXPLICIT_PROPERTIES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROPERTY_GRAPH_ENFORCE_EXPLICIT_PROPERTIES"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_JSON_SUBFIELDS_WITH_SET"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_JSON_SUBFIELDS_WITH_SET"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TABLE_SYNTAX_RESOLVE_ARGUMENT_LAST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TABLE_SYNTAX_RESOLVE_ARGUMENT_LAST"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_VALIDATE_REWRITERS_REFER_TO_BUILTINS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_VALIDATE_REWRITERS_REFER_TO_BUILTINS"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROCEDURES_IN_MODULES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROCEDURES_IN_MODULES"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_STATEMENT_WITH_PIPE_OPERATORS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_STATEMENT_WITH_PIPE_OPERATORS"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TOP_LEVEL_TABLE_STATEMENTS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TOP_LEVEL_TABLE_STATEMENTS"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ORDER_BY_COLLATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ORDER_BY_COLLATE"]._serialized_options = b'\332\361\252\211\005\003\030\370U'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_ORDER_BY_COLLATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_ORDER_BY_COLLATE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WITH_ON_SUBQUERY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WITH_ON_SUBQUERY"]._serialized_options = b'\332\361\252\211\005\003\030\370U'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_WITH_ON_SUBQUERY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_WITH_ON_SUBQUERY"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SELECT_STAR_EXCEPT_REPLACE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SELECT_STAR_EXCEPT_REPLACE"]._serialized_options = b'\332\361\252\211\005\003\030\370U'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_SELECT_STAR_EXCEPT_REPLACE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_SELECT_STAR_EXCEPT_REPLACE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ORDER_BY_IN_AGGREGATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ORDER_BY_IN_AGGREGATE"]._serialized_options = b'\332\361\252\211\005\003\030\370U'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_ORDER_BY_IN_AGGREGATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_ORDER_BY_IN_AGGREGATE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CAST_DIFFERENT_ARRAY_TYPES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CAST_DIFFERENT_ARRAY_TYPES"]._serialized_options = b'\332\361\252\211\005\003\030\370U'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_CAST_DIFFERENT_ARRAY_TYPES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_CAST_DIFFERENT_ARRAY_TYPES"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_EQUALITY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_EQUALITY"]._serialized_options = b'\332\361\252\211\005\003\030\370U'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_ARRAY_EQUALITY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_ARRAY_EQUALITY"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIMIT_IN_AGGREGATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIMIT_IN_AGGREGATE"]._serialized_options = b'\332\361\252\211\005\003\030\370U'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_LIMIT_IN_AGGREGATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_LIMIT_IN_AGGREGATE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_HAVING_IN_AGGREGATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_HAVING_IN_AGGREGATE"]._serialized_options = b'\332\361\252\211\005\003\030\370U'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_HAVING_IN_AGGREGATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_HAVING_IN_AGGREGATE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NULL_HANDLING_MODIFIER_IN_ANALYTIC"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NULL_HANDLING_MODIFIER_IN_ANALYTIC"]._serialized_options = b'\332\361\252\211\005\003\030\370U'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_NULL_HANDLING_MODIFIER_IN_ANALYTIC"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_NULL_HANDLING_MODIFIER_IN_ANALYTIC"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NULL_HANDLING_MODIFIER_IN_AGGREGATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NULL_HANDLING_MODIFIER_IN_AGGREGATE"]._serialized_options = b'\332\361\252\211\005\003\030\370U'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_NULL_HANDLING_MODIFIER_IN_AGGREGATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_NULL_HANDLING_MODIFIER_IN_AGGREGATE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FOR_SYSTEM_TIME_AS_OF"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FOR_SYSTEM_TIME_AS_OF"]._serialized_options = b'\332\361\252\211\005\003\030\370U'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_FOR_SYSTEM_TIME_AS_OF"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_1_FOR_SYSTEM_TIME_AS_OF"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CIVIL_TIME"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CIVIL_TIME"]._serialized_options = b'\332\361\252\211\005\003\030\340]'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_CIVIL_TIME"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_CIVIL_TIME"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SAFE_FUNCTION_CALL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SAFE_FUNCTION_CALL"]._serialized_options = b'\332\361\252\211\005\003\030\340]'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_SAFE_FUNCTION_CALL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_SAFE_FUNCTION_CALL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUP_BY_STRUCT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUP_BY_STRUCT"]._serialized_options = b'\332\361\252\211\005\003\030\340]'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_GROUP_BY_STRUCT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_GROUP_BY_STRUCT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROTO_EXTENSIONS_WITH_NEW"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROTO_EXTENSIONS_WITH_NEW"]._serialized_options = b'\332\361\252\211\005\003\030\340]'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_PROTO_EXTENSIONS_WITH_NEW"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_PROTO_EXTENSIONS_WITH_NEW"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUP_BY_ARRAY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUP_BY_ARRAY"]._serialized_options = b'\332\361\252\211\005\003\030\340]'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_GROUP_BY_ARRAY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_GROUP_BY_ARRAY"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROTO_EXTENSIONS_WITH_SET"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROTO_EXTENSIONS_WITH_SET"]._serialized_options = b'\332\361\252\211\005\003\030\340]'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_PROTO_EXTENSIONS_WITH_SET"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_PROTO_EXTENSIONS_WITH_SET"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CORRELATED_REFS_IN_NESTED_DML"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CORRELATED_REFS_IN_NESTED_DML"]._serialized_options = b'\332\361\252\211\005\003\030\340]'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_CORRELATED_REFS_IN_NESTED_DML"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_CORRELATED_REFS_IN_NESTED_DML"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WEEK_WITH_WEEKDAY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WEEK_WITH_WEEKDAY"]._serialized_options = b'\332\361\252\211\005\003\030\340]'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_WEEK_WITH_WEEKDAY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_WEEK_WITH_WEEKDAY"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_ELEMENTS_WITH_SET"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_ELEMENTS_WITH_SET"]._serialized_options = b'\332\361\252\211\005\003\030\340]'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_ARRAY_ELEMENTS_WITH_SET"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_ARRAY_ELEMENTS_WITH_SET"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NESTED_UPDATE_DELETE_WITH_OFFSET"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NESTED_UPDATE_DELETE_WITH_OFFSET"]._serialized_options = b'\332\361\252\211\005\003\030\340]'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_NESTED_UPDATE_DELETE_WITH_OFFSET"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_NESTED_UPDATE_DELETE_WITH_OFFSET"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GENERATED_COLUMNS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GENERATED_COLUMNS"]._serialized_options = b'\332\361\252\211\005\003\030\340]'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_GENERATED_COLUMNS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_2_GENERATED_COLUMNS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROTO_DEFAULT_IF_NULL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROTO_DEFAULT_IF_NULL"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_PROTO_DEFAULT_IF_NULL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_PROTO_DEFAULT_IF_NULL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_EXTRACT_FROM_PROTO"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_EXTRACT_FROM_PROTO"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_EXTRACT_FROM_PROTO"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_EXTRACT_FROM_PROTO"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DEPRECATED_DISALLOW_PROTO3_HAS_SCALAR_FIELD"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DEPRECATED_DISALLOW_PROTO3_HAS_SCALAR_FIELD"]._serialized_options = b'\332\361\252\211\005\005\010\000\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_DEPRECATED_DISALLOW_PROTO3_HAS_SCALAR_FIELD"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_DEPRECATED_DISALLOW_PROTO3_HAS_SCALAR_FIELD"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_ORDERING"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_ORDERING"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ARRAY_ORDERING"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ARRAY_ORDERING"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_OMIT_INSERT_COLUMN_LIST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_OMIT_INSERT_COLUMN_LIST"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_OMIT_INSERT_COLUMN_LIST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_OMIT_INSERT_COLUMN_LIST"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_IGNORE_PROTO3_USE_DEFAULTS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_IGNORE_PROTO3_USE_DEFAULTS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_IGNORE_PROTO3_USE_DEFAULTS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_IGNORE_PROTO3_USE_DEFAULTS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REPLACE_FIELDS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REPLACE_FIELDS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_REPLACE_FIELDS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_REPLACE_FIELDS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NULLS_FIRST_LAST_IN_ORDER_BY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NULLS_FIRST_LAST_IN_ORDER_BY"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_NULLS_FIRST_LAST_IN_ORDER_BY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_NULLS_FIRST_LAST_IN_ORDER_BY"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALLOW_DASHES_IN_TABLE_NAME"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALLOW_DASHES_IN_TABLE_NAME"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ALLOW_DASHES_IN_TABLE_NAME"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ALLOW_DASHES_IN_TABLE_NAME"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CONCAT_MIXED_TYPES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CONCAT_MIXED_TYPES"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_CONCAT_MIXED_TYPES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_CONCAT_MIXED_TYPES"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WITH_RECURSIVE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WITH_RECURSIVE"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_WITH_RECURSIVE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_WITH_RECURSIVE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROTO_MAPS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PROTO_MAPS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_PROTO_MAPS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_PROTO_MAPS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENUM_VALUE_DESCRIPTOR_PROTO"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENUM_VALUE_DESCRIPTOR_PROTO"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ENUM_VALUE_DESCRIPTOR_PROTO"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ENUM_VALUE_DESCRIPTOR_PROTO"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DECIMAL_ALIAS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DECIMAL_ALIAS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_DECIMAL_ALIAS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_DECIMAL_ALIAS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_UNNEST_AND_FLATTEN_ARRAYS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_UNNEST_AND_FLATTEN_ARRAYS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_UNNEST_AND_FLATTEN_ARRAYS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_UNNEST_AND_FLATTEN_ARRAYS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALLOW_CONSECUTIVE_ON"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALLOW_CONSECUTIVE_ON"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ALLOW_CONSECUTIVE_ON"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ALLOW_CONSECUTIVE_ON"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALLOW_REGEXP_EXTRACT_OPTIONALS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALLOW_REGEXP_EXTRACT_OPTIONALS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ALLOW_REGEXP_EXTRACT_OPTIONALS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ALLOW_REGEXP_EXTRACT_OPTIONALS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DATE_TIME_CONSTRUCTORS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DATE_TIME_CONSTRUCTORS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_DATE_TIME_CONSTRUCTORS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_DATE_TIME_CONSTRUCTORS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DATE_ARITHMETICS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DATE_ARITHMETICS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_DATE_ARITHMETICS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_DATE_ARITHMETICS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ADDITIONAL_STRING_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ADDITIONAL_STRING_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ADDITIONAL_STRING_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ADDITIONAL_STRING_FUNCTIONS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WITH_GROUP_ROWS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WITH_GROUP_ROWS"]._serialized_options = b'\332\361\252\211\005\007\010\000\020\001\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_WITH_GROUP_ROWS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_WITH_GROUP_ROWS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_EXTENDED_DATE_TIME_SIGNATURES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_EXTENDED_DATE_TIME_SIGNATURES"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_EXTENDED_DATE_TIME_SIGNATURES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_EXTENDED_DATE_TIME_SIGNATURES"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_EXTENDED_GEOGRAPHY_PARSERS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_EXTENDED_GEOGRAPHY_PARSERS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_EXTENDED_GEOGRAPHY_PARSERS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_EXTENDED_GEOGRAPHY_PARSERS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_INLINE_LAMBDA_ARGUMENT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_INLINE_LAMBDA_ARGUMENT"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_INLINE_LAMBDA_ARGUMENT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_INLINE_LAMBDA_ARGUMENT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIVOT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIVOT"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_PIVOT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_PIVOT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANNOTATION_FRAMEWORK"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANNOTATION_FRAMEWORK"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ANNOTATION_FRAMEWORK"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ANNOTATION_FRAMEWORK"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_COLLATION_SUPPORT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_COLLATION_SUPPORT"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_COLLATION_SUPPORT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_COLLATION_SUPPORT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_IS_DISTINCT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_IS_DISTINCT"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_IS_DISTINCT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_IS_DISTINCT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FORMAT_IN_CAST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FORMAT_IN_CAST"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_FORMAT_IN_CAST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_FORMAT_IN_CAST"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_UNPIVOT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_UNPIVOT"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_UNPIVOT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_UNPIVOT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DML_RETURNING"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DML_RETURNING"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_DML_RETURNING"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_DML_RETURNING"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FILTER_FIELDS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FILTER_FIELDS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_FILTER_FIELDS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_FILTER_FIELDS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_QUALIFY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_QUALIFY"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_QUALIFY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_QUALIFY"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REPEAT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REPEAT"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_REPEAT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_REPEAT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_COLUMN_DEFAULT_VALUE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_COLUMN_DEFAULT_VALUE"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_COLUMN_DEFAULT_VALUE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_COLUMN_DEFAULT_VALUE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FOR_IN"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FOR_IN"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_FOR_IN"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_FOR_IN"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_KLL_WEIGHTS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_KLL_WEIGHTS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_KLL_WEIGHTS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_KLL_WEIGHTS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIKE_ANY_SOME_ALL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIKE_ANY_SOME_ALL"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_LIKE_ANY_SOME_ALL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_LIKE_ANY_SOME_ALL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CASE_STMT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CASE_STMT"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_CASE_STMT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_CASE_STMT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALLOW_SLASH_PATHS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALLOW_SLASH_PATHS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ALLOW_SLASH_PATHS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ALLOW_SLASH_PATHS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TYPEOF_FUNCTION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TYPEOF_FUNCTION"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_TYPEOF_FUNCTION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_TYPEOF_FUNCTION"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SCRIPT_LABEL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SCRIPT_LABEL"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_SCRIPT_LABEL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_SCRIPT_LABEL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REMOTE_FUNCTION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REMOTE_FUNCTION"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_REMOTE_FUNCTION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_REMOTE_FUNCTION"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_GREATEST_LEAST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_GREATEST_LEAST"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ARRAY_GREATEST_LEAST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_ARRAY_GREATEST_LEAST"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_BRACED_PROTO_CONSTRUCTORS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_BRACED_PROTO_CONSTRUCTORS"]._serialized_options = b'\332\361\252\211\005\003\030\310e'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_BRACED_PROTO_CONSTRUCTORS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_3_BRACED_PROTO_CONSTRUCTORS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WITH_EXPRESSION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WITH_EXPRESSION"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_WITH_EXPRESSION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_WITH_EXPRESSION"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ORDERED_PRIMARY_KEYS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ORDERED_PRIMARY_KEYS"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ORDERED_PRIMARY_KEYS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ORDERED_PRIMARY_KEYS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TTL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TTL"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_TTL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_TTL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_BARE_ARRAY_ACCESS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_BARE_ARRAY_ACCESS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_BARE_ARRAY_ACCESS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_BARE_ARRAY_ACCESS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_AGGREGATION_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_AGGREGATION_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ARRAY_AGGREGATION_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ARRAY_AGGREGATION_FUNCTIONS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_FIND_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_FIND_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ARRAY_FIND_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ARRAY_FIND_FUNCTIONS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SAFE_FUNCTION_CALL_WITH_LAMBDA_ARGS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SAFE_FUNCTION_CALL_WITH_LAMBDA_ARGS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SAFE_FUNCTION_CALL_WITH_LAMBDA_ARGS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SAFE_FUNCTION_CALL_WITH_LAMBDA_ARGS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_ADVANCED_QUERY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_ADVANCED_QUERY"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_ADVANCED_QUERY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_ADVANCED_QUERY"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_EXPOSE_GRAPH_ELEMENT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_EXPOSE_GRAPH_ELEMENT"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_EXPOSE_GRAPH_ELEMENT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_EXPOSE_GRAPH_ELEMENT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_BOUNDED_PATH_QUANTIFICATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_BOUNDED_PATH_QUANTIFICATION"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_BOUNDED_PATH_QUANTIFICATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_BOUNDED_PATH_QUANTIFICATION"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_UNBOUNDED_PATH_QUANTIFICATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_UNBOUNDED_PATH_QUANTIFICATION"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_RETURN_EXTENSIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_RETURN_EXTENSIONS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_RETURN_EXTENSIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_RETURN_EXTENSIONS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_PATH_TYPE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_PATH_TYPE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_PATH_TYPE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_PATH_TYPE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUP_BY_GRAPH_PATH"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUP_BY_GRAPH_PATH"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_GROUP_BY_GRAPH_PATH"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_GROUP_BY_GRAPH_PATH"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_PATH_SEARCH_PREFIX_PATH_COUNT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_PATH_SEARCH_PREFIX_PATH_COUNT"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_PATH_SEARCH_PREFIX_PATH_COUNT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_PATH_SEARCH_PREFIX_PATH_COUNT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_PATH_MODE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_PATH_MODE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_PATH_MODE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_PATH_MODE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_DYNAMIC_ELEMENT_TYPE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_DYNAMIC_ELEMENT_TYPE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_ELEMENT_TYPE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_ELEMENT_TYPE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_DYNAMIC_LABEL_PROPERTIES_IN_DDL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_DYNAMIC_LABEL_PROPERTIES_IN_DDL"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_LABEL_PROPERTIES_IN_DDL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_LABEL_PROPERTIES_IN_DDL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_DYNAMIC_LABEL_EXTENSION_IN_DDL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_DYNAMIC_LABEL_EXTENSION_IN_DDL"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_LABEL_EXTENSION_IN_DDL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_LABEL_EXTENSION_IN_DDL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_DYNAMIC_MULTI_LABEL_NODES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_DYNAMIC_MULTI_LABEL_NODES"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_MULTI_LABEL_NODES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_DYNAMIC_MULTI_LABEL_NODES"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_ELEMENT_DEFINITION_NAME_IN_JSON_RESULT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_ELEMENT_DEFINITION_NAME_IN_JSON_RESULT"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_ELEMENT_DEFINITION_NAME_IN_JSON_RESULT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_ELEMENT_DEFINITION_NAME_IN_JSON_RESULT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_CHEAPEST_PATH"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_CHEAPEST_PATH"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_CHEAPEST_PATH"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_CHEAPEST_PATH"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_CALL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_CALL"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_CALL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SQL_GRAPH_CALL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_SET_OPERATION_PROPAGATION_MODE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_SET_OPERATION_PROPAGATION_MODE"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_DEFAULT_LABEL_AND_PROPERTY_DEFINITION_OPTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SQL_GRAPH_DEFAULT_LABEL_AND_PROPERTY_DEFINITION_OPTIONS"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REMOTE_MODEL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REMOTE_MODEL"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_REMOTE_MODEL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_REMOTE_MODEL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_STRUCT_POSITIONAL_ACCESSOR"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_STRUCT_POSITIONAL_ACCESSOR"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_STRUCT_POSITIONAL_ACCESSOR"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_STRUCT_POSITIONAL_ACCESSOR"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SINGLE_TABLE_NAME_ARRAY_PATH"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SINGLE_TABLE_NAME_ARRAY_PATH"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SINGLE_TABLE_NAME_ARRAY_PATH"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SINGLE_TABLE_NAME_ARRAY_PATH"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_COLLATION_IN_WITH_RECURSIVE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_COLLATION_IN_WITH_RECURSIVE"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_COLLATION_IN_WITH_RECURSIVE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_COLLATION_IN_WITH_RECURSIVE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_COLLATION_IN_EXPLICIT_CAST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_COLLATION_IN_EXPLICIT_CAST"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_COLLATION_IN_EXPLICIT_CAST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_COLLATION_IN_EXPLICIT_CAST"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LOAD_DATA_PARTITIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LOAD_DATA_PARTITIONS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LOAD_DATA_PARTITIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LOAD_DATA_PARTITIONS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_MODEL_WITH_ALIASED_QUERY_LIST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_MODEL_WITH_ALIASED_QUERY_LIST"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_CREATE_MODEL_WITH_ALIASED_QUERY_LIST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_CREATE_MODEL_WITH_ALIASED_QUERY_LIST"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LOAD_DATA_TEMP_TABLE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LOAD_DATA_TEMP_TABLE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LOAD_DATA_TEMP_TABLE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LOAD_DATA_TEMP_TABLE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CORRESPONDING"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CORRESPONDING"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_CORRESPONDING"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_CORRESPONDING"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SEQUENCE_ARG"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SEQUENCE_ARG"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SEQUENCE_ARG"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SEQUENCE_ARG"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUPING_BUILTIN"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUPING_BUILTIN"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_GROUPING_BUILTIN"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_GROUPING_BUILTIN"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUPING_SETS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUPING_SETS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_GROUPING_SETS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_GROUPING_SETS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PRESERVE_ANNOTATION_IN_IMPLICIT_CAST_IN_SCAN"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PRESERVE_ANNOTATION_IN_IMPLICIT_CAST_IN_SCAN"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_PRESERVE_ANNOTATION_IN_IMPLICIT_CAST_IN_SCAN"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_PRESERVE_ANNOTATION_IN_IMPLICIT_CAST_IN_SCAN"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CORRESPONDING_FULL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CORRESPONDING_FULL"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_CORRESPONDING_FULL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_CORRESPONDING_FULL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_BY_NAME"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_BY_NAME"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_BY_NAME"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_BY_NAME"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIKE_ANY_SOME_ALL_ARRAY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIKE_ANY_SOME_ALL_ARRAY"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LIKE_ANY_SOME_ALL_ARRAY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LIKE_ANY_SOME_ALL_ARRAY"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIKE_ANY_SOME_ALL_SUBQUERY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIKE_ANY_SOME_ALL_SUBQUERY"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LIKE_ANY_SOME_ALL_SUBQUERY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LIKE_ANY_SOME_ALL_SUBQUERY"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FIRST_AND_LAST_N"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FIRST_AND_LAST_N"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_FIRST_AND_LAST_N"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_FIRST_AND_LAST_N"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NULLIFZERO_ZEROIFNULL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_NULLIFZERO_ZEROIFNULL"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_NULLIFZERO_ZEROIFNULL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_NULLIFZERO_ZEROIFNULL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PI_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PI_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_PI_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_PI_FUNCTIONS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_FUNCTION_LANGUAGE_WITH_CONNECTION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CREATE_FUNCTION_LANGUAGE_WITH_CONNECTION"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_CREATE_FUNCTION_LANGUAGE_WITH_CONNECTION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_CREATE_FUNCTION_LANGUAGE_WITH_CONNECTION"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SINGLETON_UNNEST_INFERS_ALIAS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SINGLETON_UNNEST_INFERS_ALIAS"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SINGLETON_UNNEST_INFERS_ALIAS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SINGLETON_UNNEST_INFERS_ALIAS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_ZIP"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_ZIP"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ARRAY_ZIP"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ARRAY_ZIP"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MULTIWAY_UNNEST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MULTIWAY_UNNEST"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_MULTIWAY_UNNEST"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_MULTIWAY_UNNEST"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_USE_OPERATION_COLLATION_FOR_NULLIF"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_USE_OPERATION_COLLATION_FOR_NULLIF"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_USE_OPERATION_COLLATION_FOR_NULLIF"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_USE_OPERATION_COLLATION_FOR_NULLIF"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENABLE_EDIT_DISTANCE_BYTES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENABLE_EDIT_DISTANCE_BYTES"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ENABLE_EDIT_DISTANCE_BYTES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ENABLE_EDIT_DISTANCE_BYTES"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENABLE_FLOAT_DISTANCE_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENABLE_FLOAT_DISTANCE_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ENABLE_FLOAT_DISTANCE_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ENABLE_FLOAT_DISTANCE_FUNCTIONS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENABLE_MEASURES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENABLE_MEASURES"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ENABLE_MEASURES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ENABLE_MEASURES"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUP_BY_ALL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_GROUP_BY_ALL"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_GROUP_BY_ALL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_GROUP_BY_ALL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIMIT_OFFSET_EXPRESSIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIMIT_OFFSET_EXPRESSIONS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LIMIT_OFFSET_EXPRESSIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LIMIT_OFFSET_EXPRESSIONS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MAP_TYPE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MAP_TYPE"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_MAP_TYPE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_MAP_TYPE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_FLOAT32"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISABLE_FLOAT32"]._serialized_options = b'\332\361\252\211\005\007\010\000\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_DISABLE_FLOAT32"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_DISABLE_FLOAT32"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LITERAL_CONCATENATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LITERAL_CONCATENATION"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LITERAL_CONCATENATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LITERAL_CONCATENATION"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DOT_PRODUCT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DOT_PRODUCT"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_DOT_PRODUCT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_DOT_PRODUCT"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_OPT_IN_NEW_BEHAVIOR_NOT_LIKE_ANY_SOME_ALL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_OPT_IN_NEW_BEHAVIOR_NOT_LIKE_ANY_SOME_ALL"]._serialized_options = b'\010\001\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_OPT_IN_NEW_BEHAVIOR_NOT_LIKE_ANY_SOME_ALL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_OPT_IN_NEW_BEHAVIOR_NOT_LIKE_ANY_SOME_ALL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MANHATTAN_DISTANCE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MANHATTAN_DISTANCE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_MANHATTAN_DISTANCE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_MANHATTAN_DISTANCE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_L1_NORM"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_L1_NORM"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_L1_NORM"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_L1_NORM"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_L2_NORM"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_L2_NORM"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_L2_NORM"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_L2_NORM"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_STRUCT_BRACED_CONSTRUCTORS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_STRUCT_BRACED_CONSTRUCTORS"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_STRUCT_BRACED_CONSTRUCTORS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_STRUCT_BRACED_CONSTRUCTORS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WITH_RECURSIVE_DEPTH_MODIFIER"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_WITH_RECURSIVE_DEPTH_MODIFIER"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_WITH_RECURSIVE_DEPTH_MODIFIER"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_WITH_RECURSIVE_DEPTH_MODIFIER"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_JSON_ARRAY_VALUE_EXTRACTION_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_JSON_ARRAY_VALUE_EXTRACTION_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_JSON_ARRAY_VALUE_EXTRACTION_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_JSON_ARRAY_VALUE_EXTRACTION_FUNCTIONS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENFORCE_CONDITIONAL_EVALUATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ENFORCE_CONDITIONAL_EVALUATION"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ENFORCE_CONDITIONAL_EVALUATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ENFORCE_CONDITIONAL_EVALUATION"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_JSON_MORE_VALUE_EXTRACTION_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_JSON_MORE_VALUE_EXTRACTION_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_JSON_MORE_VALUE_EXTRACTION_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_JSON_MORE_VALUE_EXTRACTION_FUNCTIONS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_IMPLICIT_COERCION_STRING_LITERAL_TO_BYTES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_IMPLICIT_COERCION_STRING_LITERAL_TO_BYTES"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_IMPLICIT_COERCION_STRING_LITERAL_TO_BYTES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_IMPLICIT_COERCION_STRING_LITERAL_TO_BYTES"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_UUID_TYPE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_UUID_TYPE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_UUID_TYPE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_UUID_TYPE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MULTILEVEL_AGGREGATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MULTILEVEL_AGGREGATION"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_MULTILEVEL_AGGREGATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_MULTILEVEL_AGGREGATION"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_AGGREGATE_FILTERING"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_AGGREGATE_FILTERING"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_AGGREGATE_FILTERING"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_AGGREGATE_FILTERING"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REPLACE_FIELDS_ALLOW_MULTI_ONEOF"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REPLACE_FIELDS_ALLOW_MULTI_ONEOF"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_REPLACE_FIELDS_ALLOW_MULTI_ONEOF"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_REPLACE_FIELDS_ALLOW_MULTI_ONEOF"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FOR_UPDATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FOR_UPDATE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_FOR_UPDATE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_FOR_UPDATE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_KLL_FLOAT64_PRIMARY_WITH_DOUBLE_ALIAS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_KLL_FLOAT64_PRIMARY_WITH_DOUBLE_ALIAS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_KLL_FLOAT64_PRIMARY_WITH_DOUBLE_ALIAS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_KLL_FLOAT64_PRIMARY_WITH_DOUBLE_ALIAS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISALLOW_PIVOT_AND_UNPIVOT_ON_ARRAY_SCANS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_DISALLOW_PIVOT_AND_UNPIVOT_ON_ARRAY_SCANS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_DISALLOW_PIVOT_AND_UNPIVOT_ON_ARRAY_SCANS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_DISALLOW_PIVOT_AND_UNPIVOT_ON_ARRAY_SCANS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MATCH_RECOGNIZE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MATCH_RECOGNIZE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_MATCH_RECOGNIZE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_MATCH_RECOGNIZE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_INSERT_ON_CONFLICT_CLAUSE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_INSERT_ON_CONFLICT_CLAUSE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_INSERT_ON_CONFLICT_CLAUSE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_INSERT_ON_CONFLICT_CLAUSE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_BITWISE_AGGREGATE_BYTES_SIGNATURES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_BITWISE_AGGREGATE_BYTES_SIGNATURES"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_BITWISE_AGGREGATE_BYTES_SIGNATURES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_BITWISE_AGGREGATE_BYTES_SIGNATURES"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_RECURSIVE_UNION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_RECURSIVE_UNION"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_PIPE_RECURSIVE_UNION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_PIPE_RECURSIVE_UNION"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_UPDATE_CONSTRUCTOR"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_UPDATE_CONSTRUCTOR"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_UPDATE_CONSTRUCTOR"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_UPDATE_CONSTRUCTOR"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALIASES_FOR_STRING_AND_DATE_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ALIASES_FOR_STRING_AND_DATE_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ALIASES_FOR_STRING_AND_DATE_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ALIASES_FOR_STRING_AND_DATE_FUNCTIONS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_VIEWS_IN_MODULES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_VIEWS_IN_MODULES"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_VIEWS_IN_MODULES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_VIEWS_IN_MODULES"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FROM_AND_TO_PROTO_INTERVAL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_FROM_AND_TO_PROTO_INTERVAL"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_FROM_AND_TO_PROTO_INTERVAL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_FROM_AND_TO_PROTO_INTERVAL"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SIMPLIFY_PIVOT_REWRITE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_SIMPLIFY_PIVOT_REWRITE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SIMPLIFY_PIVOT_REWRITE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_SIMPLIFY_PIVOT_REWRITE"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_NAMED_WINDOWS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_NAMED_WINDOWS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_PIPE_NAMED_WINDOWS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_PIPE_NAMED_WINDOWS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TVF_PSEUDO_COLUMNS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TVF_PSEUDO_COLUMNS"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_TVF_PSEUDO_COLUMNS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_TVF_PSEUDO_COLUMNS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LATERAL_JOIN"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LATERAL_JOIN"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LATERAL_JOIN"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_LATERAL_JOIN"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CHAINED_FUNCTION_CALLS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_CHAINED_FUNCTION_CALLS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_CHAINED_FUNCTION_CALLS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_CHAINED_FUNCTION_CALLS"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TIMESTAMP_PRECISION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TIMESTAMP_PRECISION"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_TIMESTAMP_PRECISION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_TIMESTAMP_PRECISION"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TIMESTAMP_PRECISION_ANNOTATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TIMESTAMP_PRECISION_ANNOTATION"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_TIMESTAMP_PRECISION_ANNOTATION"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_TIMESTAMP_PRECISION_ANNOTATION"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANALYSIS_CONSTANT_STRUCT_POSITIONAL_ACCESSOR"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANALYSIS_CONSTANT_STRUCT_POSITIONAL_ACCESSOR"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ANALYSIS_CONSTANT_STRUCT_POSITIONAL_ACCESSOR"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_V_1_4_ANALYSIS_CONSTANT_STRUCT_POSITIONAL_ACCESSOR"]._serialized_options = b'\010\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANALYSIS_CONSTANT_FUNCTION_ARGUMENT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANALYSIS_CONSTANT_FUNCTION_ARGUMENT"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANALYSIS_CONSTANT_PIVOT_COLUMN"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANALYSIS_CONSTANT_PIVOT_COLUMN"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANALYSIS_CONSTANT_INTERVAL_CONSTRUCTOR"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ANALYSIS_CONSTANT_INTERVAL_CONSTRUCTOR"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REPORT_FORMAT_CONSTANT_ARGUMENT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_REPORT_FORMAT_CONSTANT_ARGUMENT"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_DESCRIBE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_DESCRIBE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MULTI_GROUPING_SETS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MULTI_GROUPING_SETS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_CALL_INPUT_TABLE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_PIPE_CALL_INPUT_TABLE"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_RELAXED_WITH_RECURSIVE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_RELAXED_WITH_RECURSIVE"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_RUN_STATEMENT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_RUN_STATEMENT"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIMIT_ALL"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LIMIT_ALL"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ADDITIONAL_DATE_TIME_FUNCTIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ADDITIONAL_DATE_TIME_FUNCTIONS"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_KLL_QUANTILES_EXTRACT_RELATIVE_RANK"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_KLL_QUANTILES_EXTRACT_RELATIVE_RANK"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MATCH_MAKE_STRUCT_IN_GROUP_BY"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MATCH_MAKE_STRUCT_IN_GROUP_BY"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_CONSTRUCTOR_EXPLICIT_TYPE_ENFORCE_TARGET_ANNOTATIONS"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ARRAY_CONSTRUCTOR_EXPLICIT_TYPE_ENFORCE_TARGET_ANNOTATIONS"]._serialized_options = b'\332\361\252\211\005\003\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LATERAL_COLUMN_REFERENCES"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_LATERAL_COLUMN_REFERENCES"]._serialized_options = b'\332\361\252\211\005\004\010\000\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ROW_TYPE"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_ROW_TYPE"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MEASURES_TVF"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_MEASURES_TVF"]._serialized_options = b'\332\361\252\211\005\005\020\001\030\260m'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TEST_IDEALLY_ENABLED_BUT_IN_DEVELOPMENT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TEST_IDEALLY_ENABLED_BUT_IN_DEVELOPMENT"]._serialized_options = b'\332\361\252\211\005\002\020\001'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TEST_IDEALLY_DISABLED"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TEST_IDEALLY_DISABLED"]._serialized_options = b'\332\361\252\211\005\002\010\000'
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TEST_IDEALLY_DISABLED_AND_IN_DEVELOPMENT"]._loaded_options = None
  _globals['_LANGUAGEFEATURE'].values_by_name["FEATURE_TEST_IDEALLY_DISABLED_AND_IN_DEVELOPMENT"]._serialized_options = b'\332\361\252\211\005\004\010\000\020\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_FLATTEN"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_FLATTEN"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_ANONYMIZATION"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_ANONYMIZATION"]._serialized_options = b'\202\207\335\204\n\002\010\000'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_PROTO_MAP_FNS"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_PROTO_MAP_FNS"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_ARRAY_FILTER_TRANSFORM"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_ARRAY_FILTER_TRANSFORM"]._serialized_options = b'\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_UNPIVOT"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_UNPIVOT"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_PIVOT"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_PIVOT"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_ARRAY_INCLUDES"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_ARRAY_INCLUDES"]._serialized_options = b'\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_TYPEOF_FUNCTION"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_TYPEOF_FUNCTION"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_WITH_EXPR"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_WITH_EXPR"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_INLINE_SQL_FUNCTIONS"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_INLINE_SQL_FUNCTIONS"]._serialized_options = b'\202\207\335\204\n\002\010\000'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_INLINE_SQL_TVFS"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_INLINE_SQL_TVFS"]._serialized_options = b'\202\207\335\204\n\004\010\000\020\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_NULLIFERROR_FUNCTION"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_NULLIFERROR_FUNCTION"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_LIKE_ANY_ALL"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_LIKE_ANY_ALL"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_BUILTIN_FUNCTION_INLINER"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_BUILTIN_FUNCTION_INLINER"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_INLINE_SQL_VIEWS"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_INLINE_SQL_VIEWS"]._serialized_options = b'\202\207\335\204\n\004\010\001\020\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_INLINE_SQL_UDAS"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_INLINE_SQL_UDAS"]._serialized_options = b'\202\207\335\204\n\002\010\000'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_GROUPING_SET"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_GROUPING_SET"]._serialized_options = b'\202\207\335\204\n\004\010\001\020\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_INSERT_DML_VALUES"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_INSERT_DML_VALUES"]._serialized_options = b'\202\207\335\204\n\002\010\000'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_MULTIWAY_UNNEST"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_MULTIWAY_UNNEST"]._serialized_options = b'\202\207\335\204\n\004\010\000\020\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_AGGREGATION_THRESHOLD"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_AGGREGATION_THRESHOLD"]._serialized_options = b'\202\207\335\204\n\002\010\000'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_PIPE_ASSERT"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_PIPE_ASSERT"]._serialized_options = b'\202\207\335\204\n\004\010\000\020\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_ORDER_BY_AND_LIMIT_IN_AGGREGATE"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_ORDER_BY_AND_LIMIT_IN_AGGREGATE"]._serialized_options = b'\202\207\335\204\n\002\010\000'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_PIPE_IF"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_PIPE_IF"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_GENERALIZED_QUERY_STMT"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_GENERALIZED_QUERY_STMT"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_IS_FIRST_IS_LAST_FUNCTION"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_IS_FIRST_IS_LAST_FUNCTION"]._serialized_options = b'\202\207\335\204\n\004\010\000\020\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_MATCH_RECOGNIZE_FUNCTION"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_MATCH_RECOGNIZE_FUNCTION"]._serialized_options = b'\202\207\335\204\n\004\010\000\020\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_MEASURE_TYPE"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_MEASURE_TYPE"]._serialized_options = b'\202\207\335\204\n\002\010\000'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_APPLY_ENABLED_REWRITES_TO_TEMPLATED_FUNCTION_CALLS"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_APPLY_ENABLED_REWRITES_TO_TEMPLATED_FUNCTION_CALLS"]._serialized_options = b'\202\207\335\204\n\002\010\000'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_UPDATE_CONSTRUCTOR"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_UPDATE_CONSTRUCTOR"]._serialized_options = b'\202\207\335\204\n\004\010\001\020\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_PIPE_DESCRIBE"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_PIPE_DESCRIBE"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_SUBPIPELINE_STMT"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_SUBPIPELINE_STMT"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_ROW_TYPE"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_ROW_TYPE"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_VARIADIC_FUNCTION_SIGNATURE_EXPANDER"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_VARIADIC_FUNCTION_SIGNATURE_EXPANDER"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_TEST_DEFAULT_DISABLED"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_TEST_DEFAULT_DISABLED"]._serialized_options = b'\202\207\335\204\n\002\010\000'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_TEST_DEFAULT_ENABLED"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_TEST_DEFAULT_ENABLED"]._serialized_options = b'\202\207\335\204\n\002\010\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_TEST_DEFAULT_DISABLED_AND_IN_DEVELOPMENT"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_TEST_DEFAULT_DISABLED_AND_IN_DEVELOPMENT"]._serialized_options = b'\202\207\335\204\n\004\010\000\020\001'
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_TEST_DEFAULT_ENABLED_AND_IN_DEVELOPMENT"]._loaded_options = None
  _globals['_RESOLVEDASTREWRITE'].values_by_name["REWRITE_TEST_DEFAULT_ENABLED_AND_IN_DEVELOPMENT"]._serialized_options = b'\202\207\335\204\n\004\010\001\020\001'
  _globals['_LANGUAGEVERSION']._serialized_start=583
  _globals['_LANGUAGEVERSION']._serialized_end=807
  _globals['_LANGUAGEFEATURE']._serialized_start=811
  _globals['_LANGUAGEFEATURE']._serialized_end=22956
  _globals['_RESOLVEDASTREWRITE']._serialized_start=22959
  _globals['_RESOLVEDASTREWRITE']._serialized_end=24618
  _globals['_NAMERESOLUTIONMODE']._serialized_start=24620
  _globals['_NAMERESOLUTIONMODE']._serialized_end=24697
  _globals['_PRODUCTMODE']._serialized_start=24699
  _globals['_PRODUCTMODE']._serialized_end=24756
  _globals['_STATEMENTCONTEXT']._serialized_start=24758
  _globals['_STATEMENTCONTEXT']._serialized_end=24817
  _globals['_ERRORMESSAGEMODE']._serialized_start=24819
  _globals['_ERRORMESSAGEMODE']._serialized_end=24938
  _globals['_ERRORMESSAGESTABILITY']._serialized_start=24941
  _globals['_ERRORMESSAGESTABILITY']._serialized_end=25247
  _globals['_PARAMETERMODE']._serialized_start=25249
  _globals['_PARAMETERMODE']._serialized_end=25331
  _globals['_PARSELOCATIONRECORDTYPE']._serialized_start=25334
  _globals['_PARSELOCATIONRECORDTYPE']._serialized_end=25473
  _globals['_LANGUAGEFEATUREOPTIONS']._serialized_start=76
  _globals['_LANGUAGEFEATUREOPTIONS']._serialized_end=214
  _globals['_RESOLVEDASTREWRITEOPTIONS']._serialized_start=216
  _globals['_RESOLVEDASTREWRITEOPTIONS']._serialized_end=299
  _globals['_REWRITEOPTIONS']._serialized_start=301
  _globals['_REWRITEOPTIONS']._serialized_end=402
  _globals['_GROUPINGSETREWRITEOPTIONS']._serialized_start=404
  _globals['_GROUPINGSETREWRITEOPTIONS']._serialized_end=509
  _globals['_ERRORMESSAGEMODEFORPAYLOAD']._serialized_start=511
  _globals['_ERRORMESSAGEMODEFORPAYLOAD']._serialized_end=580
# @@protoc_insertion_point(module_scope)
